@@ -1,4 +1,4 @@
-// Copyright (C) 2016-2025 Internet Systems Consortium, Inc. ("ISC")
+// Copyright (C) 2016-2024 Internet Systems Consortium, Inc. ("ISC")
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -12,9 +12,7 @@
 #include <agent/ca_command_mgr.h>
 #include <cc/data.h>
 #include <cc/command_interpreter.h>
-#include <config/unix_command_config.h>
 #include <process/testutils/d_test_stubs.h>
-#include <util/filesystem.h>
 #include <testutils/gtest_utils.h>
 
 #include <boost/pointer_cast.hpp>
@@ -28,8 +26,6 @@ using namespace isc::agent;
 using namespace isc::data;
 using namespace isc::http;
 using namespace isc::process;
-using namespace isc::config;
-using namespace isc::util;
 using namespace boost::posix_time;
 using namespace std;
 
@@ -43,11 +39,11 @@ const char* valid_agent_config =
     "  \"control-sockets\": {"
     "    \"dhcp4\": {"
     "      \"socket-type\": \"unix\","
-    "      \"socket-name\": \"first_socket4\""
+    "      \"socket-name\": \"/first/dhcp4/socket\""
     "    },"
     "    \"dhcp6\": {"
     "      \"socket-type\": \"unix\","
-    "      \"socket-name\": \"first_socket6\""
+    "      \"socket-name\": \"/first/dhcp6/socket\""
     "    }"
     "  }"
     "}";
@@ -64,12 +60,6 @@ public:
     /// @brief Constructor.
     CtrlAgentControllerTest()
         : DControllerTest(CtrlAgentController::instance) {
-        setSocketTestPath();
-    }
-
-    /// @brief Destructor.
-    virtual ~CtrlAgentControllerTest() {
-        resetSocketPath();
     }
 
     /// @brief Returns pointer to CtrlAgentProcess instance.
@@ -95,20 +85,6 @@ public:
         return (p);
     }
 
-    /// @brief Sets the path in which the socket can be created.
-    /// @param explicit_path path to use as the socket path.
-    void setSocketTestPath(const std::string explicit_path = "") {
-        auto path = UnixCommandConfig::getSocketPath(true, (!explicit_path.empty() ?
-                                                     explicit_path : TEST_DATA_BUILDDIR));
-        UnixCommandConfig::setSocketPathPerms(file::getPermissions(path));
-    }
-
-    /// @brief Resets the socket path to the default.
-    void resetSocketPath() {
-        UnixCommandConfig::getSocketPath(true);
-        UnixCommandConfig::setSocketPathPerms();
-    }
-
     /// @brief Tests that socket info structure contains 'unix' socket-type
     /// value and the expected socket-name.
     ///
@@ -124,7 +100,8 @@ public:
         ASSERT_TRUE(sock_info->contains("socket-type"));
         EXPECT_EQ("unix", sock_info->get("socket-type")->stringValue());
         ASSERT_TRUE(sock_info->contains("socket-name"));
-        EXPECT_EQ(exp_socket_name, sock_info->get("socket-name")->stringValue());
+        EXPECT_EQ(exp_socket_name,
+                  sock_info->get("socket-name")->stringValue());
     }
 
     /// @brief Compares the status in the given parse result to a given value.
@@ -211,6 +188,7 @@ TEST_F(CtrlAgentControllerTest, basicInstanceTesting) {
     EXPECT_FALSE(checkProcess());
 }
 
+
 // Tests basic command line processing.
 // Verifies that:
 // 1. Standard command line options are supported.
@@ -226,7 +204,7 @@ TEST_F(CtrlAgentControllerTest, commandLineArgs) {
     EXPECT_TRUE(checkVerbose(false));
 
     // Verify that standard options can be parsed without error.
-    EXPECT_NO_THROW(parseArgs(argc, argv));
+    EXPECT_NO_THROW_LOG(parseArgs(argc, argv));
 
     // Verify that verbose flag is true.
     EXPECT_TRUE(checkVerbose(true));
@@ -238,7 +216,7 @@ TEST_F(CtrlAgentControllerTest, commandLineArgs) {
     char* argv2[] = { const_cast<char*>("progName"),
                       const_cast<char*>("-x") };
     argc = 2;
-    EXPECT_THROW(parseArgs(argc, argv2), InvalidUsage);
+    EXPECT_THROW_MSG(parseArgs(argc, argv2), InvalidUsage, "unsupported option: -x");
 }
 
 // Tests application process creation and initialization.
@@ -302,11 +280,11 @@ TEST_F(CtrlAgentControllerTest, successfulConfigUpdate) {
         "  \"control-sockets\": {"
         "    \"dhcp4\": {"
         "      \"socket-type\": \"unix\","
-        "      \"socket-name\": \"second_socket4\""
+        "      \"socket-name\": \"/second/dhcp4/socket\""
         "    },"
         "    \"dhcp6\": {"
         "      \"socket-type\": \"unix\","
-        "      \"socket-name\": \"second_socket6\""
+        "      \"socket-name\": \"/second/dhcp6/socket\""
         "    }"
         "  }"
         "}";
@@ -345,8 +323,8 @@ TEST_F(CtrlAgentControllerTest, successfulConfigUpdate) {
     EXPECT_EQ(8080, ctx->getHttpPort());
 
     // The forwarding configuration should have been updated too.
-    testUnixSocketInfo("dhcp4", "second_socket4");
-    testUnixSocketInfo("dhcp6", "second_socket6");
+    testUnixSocketInfo("dhcp4", "/second/dhcp4/socket");
+    testUnixSocketInfo("dhcp6", "/second/dhcp6/socket");
 
     // After the shutdown the HTTP listener no longer exists.
     CtrlAgentProcessPtr process = getCtrlAgentProcess();
@@ -368,11 +346,11 @@ TEST_F(CtrlAgentControllerTest, unsuccessfulConfigUpdate) {
         "  \"control-sockets\": {"
         "    \"dhcp4\": {"
         "      \"socket-type\": \"unix\","
-        "      \"socket-name\": \"second_socket4\""
+        "      \"socket-name\": \"/second/dhcp4/socket\""
         "    },"
         "    \"dhcp6\": {"
         "      \"socket-type\": \"unix\","
-        "      \"socket-name\": \"second_socket6\""
+        "      \"socket-name\": \"/second/dhcp6/socket\""
         "    }"
         "  }"
         "}";
@@ -411,8 +389,8 @@ TEST_F(CtrlAgentControllerTest, unsuccessfulConfigUpdate) {
     EXPECT_EQ(8081, ctx->getHttpPort());
 
     // Same for forwarding.
-    testUnixSocketInfo("dhcp4", "first_socket4");
-    testUnixSocketInfo("dhcp6", "first_socket6");
+    testUnixSocketInfo("dhcp4", "/first/dhcp4/socket");
+    testUnixSocketInfo("dhcp6", "/first/dhcp6/socket");
 
     // After the shutdown the HTTP listener no longer exists.
     CtrlAgentProcessPtr process = getCtrlAgentProcess();
@@ -434,11 +412,11 @@ TEST_F(CtrlAgentControllerTest, noListenerChange) {
         "  \"control-sockets\": {"
         "    \"dhcp4\": {"
         "      \"socket-type\": \"unix\","
-        "      \"socket-name\": \"second_socket4\""
+        "      \"socket-name\": \"/second/dhcp4/socket\""
         "    },"
         "    \"dhcp6\": {"
         "      \"socket-type\": \"unix\","
-        "      \"socket-name\": \"second_socket6\""
+        "      \"socket-name\": \"/second/dhcp6/socket\""
         "    }"
         "  }"
         "}";
@@ -476,8 +454,8 @@ TEST_F(CtrlAgentControllerTest, noListenerChange) {
     EXPECT_EQ(8081, ctx->getHttpPort());
 
     // The forwarding configuration should have been updated.
-    testUnixSocketInfo("dhcp4", "second_socket4");
-    testUnixSocketInfo("dhcp6", "second_socket6");
+    testUnixSocketInfo("dhcp4", "/second/dhcp4/socket");
+    testUnixSocketInfo("dhcp6", "/second/dhcp6/socket");
 
     CtrlAgentProcessPtr process = getCtrlAgentProcess();
     ASSERT_TRUE(process);
@@ -538,9 +516,6 @@ TEST_F(CtrlAgentControllerTest, configWrite) {
     // Now clean up after ourselves.
     ctrl->registerCommands();
 
-    // Add a config file.
-    ctrl->setConfigFile(string(TEST_DATA_BUILDDIR) + string("/config.json"));
-
     // First, build the command:
     string file = string(TEST_DATA_BUILDDIR) + string("/config-write.json");
     string cmd_txt = "{ \"command\": \"config-write\" }";
@@ -576,54 +551,6 @@ TEST_F(CtrlAgentControllerTest, configWrite) {
     ctrl->deregisterCommands();
 }
 
-// Tests that config-write fails with a bad path.
-TEST_F(CtrlAgentControllerTest, badConfigWrite) {
-    ASSERT_NO_THROW(initProcess());
-    EXPECT_TRUE(checkProcess());
-
-    // The framework available makes it very difficult to test the actual
-    // code as CtrlAgentController is not initialized the same way it is
-    // in production code. In particular, the way CtrlAgentController
-    // is initialized in tests does not call registerCommands().
-    // This is a crude workaround for this problem. Proper solution should
-    // be developed sooner rather than later.
-    const DControllerBasePtr& base = getController();
-    const CtrlAgentControllerPtr& ctrl
-        = boost::dynamic_pointer_cast<CtrlAgentController>(base);
-    ASSERT_TRUE(ctrl);
-    // Now clean up after ourselves.
-    ctrl->registerCommands();
-
-    // Add a config file.
-    ctrl->setConfigFile(string(TEST_DATA_BUILDDIR) + string("/config.json"));
-
-    // First, build the command:
-    string file("/tmp/config-write.json");
-    string cmd_txt = "{ \"command\": \"config-write\" }";
-    ConstElementPtr cmd = Element::fromJSON(cmd_txt);
-    ConstElementPtr params = Element::fromJSON("{\"filename\": \"" + file + "\" }");
-    CtrlAgentCommandMgr& mgr_ =  CtrlAgentCommandMgr::instance();
-
-    // Send the command
-    ConstElementPtr answer = mgr_.handleCommand("config-write", params, cmd);
-
-    // Check that the command failed.
-    string expected = "not allowed to write config into ";
-    expected += file;
-    expected += ": file ";
-    expected += file;
-    expected += " must be in the same directory as the config file (";
-    expected += string(TEST_DATA_BUILDDIR) + string("/config.json");
-    expected += ")";
-    checkAnswer(answer, isc::config::CONTROL_RESULT_ERROR, expected);
-
-    // Remove the file.
-    ::remove(file.c_str());
-
-    // Now clean up after ourselves.
-    ctrl->deregisterCommands();
-}
-
 // Tests if config-reload attempts to reload a file and reports that the
 // file is missing.
 TEST_F(CtrlAgentControllerTest, configReloadMissingFile) {
@@ -753,6 +680,7 @@ TEST_F(CtrlAgentControllerTest, configReloadFileValid) {
     answer = CtrlAgentCommandMgr::instance().handleCommand("config-reload",
                                                            params, cmd);
 
+
     // Verify the reload was successful.
     string expected = "{ \"result\": 0, \"text\": "
         "\"Configuration applied successfully.\" }";
@@ -857,6 +785,7 @@ TEST_F(CtrlAgentControllerTest, shutdown) {
     ctrl->deregisterCommands();
 }
 
+
 TEST_F(CtrlAgentControllerTest, shutdownExitValue) {
     ASSERT_NO_THROW(initProcess());
     EXPECT_TRUE(checkProcess());
