@@ -1,4 +1,4 @@
-// Copyright (C) 2012-2023 Internet Systems Consortium, Inc. ("ISC")
+// Copyright (C) 2012-2024 Internet Systems Consortium, Inc. ("ISC")
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -49,7 +49,6 @@
 #include <util/triplet.h>
 
 #include <boost/algorithm/string.hpp>
-#include <boost/foreach.hpp>
 #include <boost/lexical_cast.hpp>
 #include <boost/scoped_ptr.hpp>
 #include <boost/shared_ptr.hpp>
@@ -109,7 +108,7 @@ public:
     /// @param cfg server configuration (RSOO will be stored here)
     void parse(const SrvConfigPtr& cfg, const isc::data::ConstElementPtr& value) {
         try {
-            BOOST_FOREACH(ConstElementPtr source_elem, value->listValue()) {
+            for (auto const& source_elem : value->listValue()) {
                 std::string option_str = source_elem->stringValue();
                 // This option can be either code (integer) or name. Let's try code first
                 int64_t code = 0;
@@ -245,10 +244,10 @@ public:
         }
 
         // Let's go through all the networks one by one
-        for (auto net = networks->begin(); net != networks->end(); ++net) {
+        for (auto const& net : *networks) {
 
             // For each network go through all the subnets in it.
-            const Subnet6SimpleCollection* subnets = (*net)->getAllSubnets();
+            const Subnet6SimpleCollection* subnets = net->getAllSubnets();
             if (!subnets) {
                 // Shared network without subnets it weird, but we decided to
                 // accept such configurations.
@@ -256,8 +255,8 @@ public:
             }
 
             // For each subnet, add it to a list of regular subnets.
-            for (auto subnet = subnets->begin(); subnet != subnets->end(); ++subnet) {
-                dest->add(*subnet);
+            for (auto const& subnet : *subnets) {
+                dest->add(subnet);
             }
         }
     }
@@ -305,75 +304,74 @@ public:
         std::set<string> names;
 
         // Let's go through all the networks one by one
-        for (auto net = networks.begin(); net != networks.end(); ++net) {
+        for (auto const& net : networks) {
             string txt;
 
             // Let's check if all subnets have either the same interface
             // or don't have the interface specified at all.
-            string iface = (*net)->getIface();
+            string iface = net->getIface();
 
-            const Subnet6SimpleCollection* subnets = (*net)->getAllSubnets();
+            const Subnet6SimpleCollection* subnets = net->getAllSubnets();
             if (subnets) {
 
                 bool rapid_commit = false;
 
-                // For each subnet, add it to a list of regular subnets.
-                for (auto subnet = subnets->begin(); subnet != subnets->end(); ++subnet) {
+                // Rapid commit must either be enabled or disabled in all subnets
+                // in the shared network.
+                if (subnets->size()) {
+                    // If this is the first subnet, remember the value.
+                    rapid_commit = (*subnets->begin())->getRapidCommit();
+                }
 
-                    // Rapid commit must either be enabled or disabled in all subnets
-                    // in the shared network.
-                    if (subnet == subnets->begin()) {
-                        // If this is the first subnet, remember the value.
-                        rapid_commit = (*subnet)->getRapidCommit();
-                    } else {
-                        // Ok, this is the second or following subnets. The value
-                        // must match what was set in the first subnet.
-                        if (rapid_commit != (*subnet)->getRapidCommit()) {
-                            isc_throw(DhcpConfigError, "All subnets in a shared network "
-                                      "must have the same rapid-commit value. Subnet "
-                                      << (*subnet)->toText()
-                                      << " has specified rapid-commit "
-                                      << ( (*subnet)->getRapidCommit() ? "true" : "false")
-                                      << ", but earlier subnet in the same shared-network"
-                                      << " or the shared-network itself used rapid-commit "
-                                      << (rapid_commit ? "true" : "false"));
-                        }
+                // For each subnet, add it to a list of regular subnets.
+                for (auto const& subnet : *subnets) {
+                    // Ok, this is the second or following subnets. The value
+                    // must match what was set in the first subnet.
+                    if (rapid_commit != subnet->getRapidCommit()) {
+                        isc_throw(DhcpConfigError, "All subnets in a shared network "
+                                  "must have the same rapid-commit value. Subnet "
+                                  << subnet->toText()
+                                  << " has specified rapid-commit "
+                                  << (subnet->getRapidCommit() ? "true" : "false")
+                                  << ", but earlier subnet in the same shared-network"
+                                  << " or the shared-network itself used rapid-commit "
+                                  << (rapid_commit ? "true" : "false"));
                     }
 
                     if (iface.empty()) {
-                        iface = (*subnet)->getIface();
+                        iface = subnet->getIface();
                         continue;
                     }
 
-                    if ((*subnet)->getIface().empty()) {
+                    if (subnet->getIface().empty()) {
                         continue;
                     }
 
-                    if ((*subnet)->getIface() != iface) {
-                        isc_throw(DhcpConfigError, "Subnet " << (*subnet)->toText()
-                                  << " has specified interface " << (*subnet)->getIface()
+                    if (subnet->getIface() != iface) {
+                        isc_throw(DhcpConfigError, "Subnet " << subnet->toText()
+                                  << " has specified interface " << subnet->getIface()
                                   << ", but earlier subnet in the same shared-network"
                                   << " or the shared-network itself used " << iface);
                     }
 
                     // Let's collect the subnets in case we later find out the
                     // subnet doesn't have a mandatory name.
-                    txt += (*subnet)->toText() + " ";
+                    txt += subnet->toText() + " ";
                 }
             }
 
             // Next, let's check name of the shared network.
-            if ((*net)->getName().empty()) {
+            if (net->getName().empty()) {
                 isc_throw(DhcpConfigError, "Shared-network with subnets "
                           << txt << " is missing mandatory 'name' parameter");
             }
 
             // Is it unique?
-            if (names.find((*net)->getName()) != names.end()) {
+            if (names.find(net->getName()) != names.end()) {
                 isc_throw(DhcpConfigError, "A shared-network with "
-                          "name " << (*net)->getName() << " defined twice.");
+                          "name " << net->getName() << " defined twice.");
             }
-            names.insert((*net)->getName());
+            names.insert(net->getName());
 
         }
     }
@@ -586,7 +584,7 @@ processDhcp6Config(isc::data::ConstElementPtr config_set) {
         if (expiration_cfg) {
             parameter_name = "expired-leases-processing";
             ExpirationConfigParser parser;
-            parser.parse(expiration_cfg);
+            parser.parse(expiration_cfg, CfgMgr::instance().getStagingCfg()->getCfgExpiration());
         }
 
         // The hooks-libraries configuration must be parsed after parsing
@@ -649,7 +647,7 @@ processDhcp6Config(isc::data::ConstElementPtr config_set) {
         if (hosts_databases) {
             parameter_name = "hosts-databases";
             CfgDbAccessPtr cfg_db_access = srv_config->getCfgDbAccess();
-            for (auto it : hosts_databases->listValue()) {
+            for (auto const& it : hosts_databases->listValue()) {
                 db::DbAccessParser parser;
                 std::string access_string;
                 parser.parse(access_string, it);
@@ -689,8 +687,8 @@ processDhcp6Config(isc::data::ConstElementPtr config_set) {
             HostCollection hosts;
             HostReservationsListParser<HostReservationParser6> parser;
             parser.parse(SUBNET_ID_GLOBAL, reservations, hosts);
-            for (auto h = hosts.begin(); h != hosts.end(); ++h) {
-                srv_config->getCfgHosts()->add(*h);
+            for (auto const& h : hosts) {
+                srv_config->getCfgHosts()->add(h);
             }
         }
 
@@ -711,32 +709,15 @@ processDhcp6Config(isc::data::ConstElementPtr config_set) {
 
         ConstElementPtr compatibility = mutable_cfg->get("compatibility");
         if (compatibility) {
-            for (auto kv : compatibility->mapValue()) {
-                if (!kv.second || (kv.second->getType() != Element::boolean)) {
-                    isc_throw(DhcpConfigError,
-                              "compatibility parameter values must be "
-                              << "boolean (" << kv.first << " at "
-                              << kv.second->getPosition() << ")");
-                }
-                if (kv.first == "lenient-option-parsing") {
-                    CfgMgr::instance().getStagingCfg()->setLenientOptionParsing(
-                        kv.second->boolValue());
-                } else {
-                    isc_throw(DhcpConfigError,
-                              "unsupported compatibility parameter: "
-                              << kv.first << " (" << kv.second->getPosition()
-                              << ")");
-                }
-            }
+            CompatibilityParser parser;
+            parser.parse(compatibility, *CfgMgr::instance().getStagingCfg());
         }
 
         // Make parsers grouping.
-        ConfigPair config_pair;
         const std::map<std::string, ConstElementPtr>& values_map =
             mutable_cfg->mapValue();
 
-        BOOST_FOREACH(config_pair, values_map) {
-
+        for (auto const& config_pair : values_map) {
             parameter_name = config_pair.first;
 
             // These are converted to SimpleParser and are handled already above.
