@@ -1,4 +1,4 @@
-// Copyright (C) 2018-2021 Internet Systems Consortium, Inc. ("ISC")
+// Copyright (C) 2018-2023 Internet Systems Consortium, Inc. ("ISC")
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -14,6 +14,7 @@
 #include <exceptions/exceptions.h>
 #include <dhcp/hwaddr.h>
 #include <dhcpsrv/lease.h>
+#include <dhcpsrv/network_state.h>
 #include <boost/pointer_cast.hpp>
 #include <gtest/gtest.h>
 #include <vector>
@@ -150,7 +151,8 @@ testCommandBasics(const ConstElementPtr& command,
 // This test verifies that the dhcp-disable command is correct.
 TEST(CommandCreatorTest, createDHCPDisable4) {
     // Create command with max-period value set to 20.
-    ConstElementPtr command = CommandCreator::createDHCPDisable(20, HAServerType::DHCPv4);
+    ConstElementPtr command = CommandCreator::createDHCPDisable(NetworkState::HA_REMOTE_COMMAND+1, 20,
+                                                                HAServerType::DHCPv4);
     ConstElementPtr arguments;
     ASSERT_NO_FATAL_FAILURE(testCommandBasics(command, "dhcp-disable", "dhcp4",
                                               arguments));
@@ -161,40 +163,52 @@ TEST(CommandCreatorTest, createDHCPDisable4) {
     EXPECT_EQ(20, max_period->intValue());
     ConstElementPtr origin = arguments->get("origin");
     ASSERT_TRUE(origin);
-    ASSERT_EQ("ha-partner", origin->stringValue());
+    ASSERT_EQ(NetworkState::HA_REMOTE_COMMAND+1, origin->intValue());
 
     // Repeat the test but this time the max-period is not specified.
-    command = CommandCreator::createDHCPDisable(0, HAServerType::DHCPv4);
+    command = CommandCreator::createDHCPDisable(NetworkState::HA_REMOTE_COMMAND+1, 0,
+                                                HAServerType::DHCPv4);
     ASSERT_NO_FATAL_FAILURE(testCommandBasics(command, "dhcp-disable", "dhcp4",
                                               arguments));
     ASSERT_EQ(1, arguments->size());
     origin = arguments->get("origin");
     ASSERT_TRUE(origin);
-    ASSERT_EQ("ha-partner", origin->stringValue());
+    ASSERT_EQ(NetworkState::HA_REMOTE_COMMAND+1, origin->intValue());
 }
 
 // This test verifies that the dhcp-enable command is correct.
 TEST(CommandCreatorTest, createDHCPEnable4) {
     ConstElementPtr arguments;
-    ConstElementPtr command = CommandCreator::createDHCPEnable(HAServerType::DHCPv4);
+    ConstElementPtr command = CommandCreator::createDHCPEnable(NetworkState::HA_REMOTE_COMMAND+1,
+                                                               HAServerType::DHCPv4);
     ASSERT_NO_FATAL_FAILURE(testCommandBasics(command, "dhcp-enable", "dhcp4",
                                               arguments));
     ASSERT_EQ(1, arguments->size());
     ConstElementPtr origin = arguments->get("origin");
     ASSERT_TRUE(origin);
-    ASSERT_EQ("ha-partner", origin->stringValue());
+    ASSERT_EQ(NetworkState::HA_REMOTE_COMMAND+1, origin->intValue());
 }
 
 // This test verifies that the ha-reset command sent to DHCPv4 server is correct.
 TEST(CommandCreatorTest, createHAReset4) {
-    ConstElementPtr command = CommandCreator::createHAReset(HAServerType::DHCPv4);
-    ASSERT_NO_FATAL_FAILURE(testCommandBasics(command, "ha-reset", "dhcp4"));
+    ConstElementPtr command = CommandCreator::createHAReset("server1", HAServerType::DHCPv4);
+    ConstElementPtr arguments;
+    ASSERT_NO_FATAL_FAILURE(testCommandBasics(command, "ha-reset", "dhcp4", arguments));
+    auto server_name = arguments->get("server-name");
+    ASSERT_TRUE(server_name);
+    ASSERT_EQ(Element::string, server_name->getType());
+    EXPECT_EQ("server1", server_name->stringValue());
 }
 
 // This test verifies that the ha-heartbeat command is correct.
 TEST(CommandCreatorTest, createHeartbeat4) {
-    ConstElementPtr command = CommandCreator::createHeartbeat(HAServerType::DHCPv4);
-    ASSERT_NO_FATAL_FAILURE(testCommandBasics(command, "ha-heartbeat", "dhcp4"));
+    ConstElementPtr command = CommandCreator::createHeartbeat("server1", HAServerType::DHCPv4);
+    ConstElementPtr arguments;
+    ASSERT_NO_FATAL_FAILURE(testCommandBasics(command, "ha-heartbeat", "dhcp4", arguments));
+    auto server_name = arguments->get("server-name");
+    ASSERT_TRUE(server_name);
+    ASSERT_EQ(Element::string, server_name->getType());
+    EXPECT_EQ("server1", server_name->stringValue());
 }
 
 // This test verifies that the command generated for the lease update
@@ -208,6 +222,7 @@ TEST(CommandCreatorTest, createLease4Update) {
     // The lease update must contain the "force-create" parameter indicating that
     // the lease must be created if it doesn't exist.
     lease_as_json->set("force-create", Element::create(true));
+    lease_as_json->set("origin", Element::create("ha-partner"));
     EXPECT_EQ(lease_as_json->str(), arguments->str());
 }
 
@@ -219,6 +234,7 @@ TEST(CommandCreatorTest, createLease4Delete) {
     ASSERT_NO_FATAL_FAILURE(testCommandBasics(command, "lease4-del", "dhcp4",
                                               arguments));
     ElementPtr lease_as_json = leaseAsJson(createLease4());
+    lease_as_json->set("origin", Element::create("ha-partner"));
     EXPECT_EQ(lease_as_json->str(), arguments->str());
 }
 
@@ -281,7 +297,8 @@ TEST(CommandCreatorTest, createLease4GetPageZeroLimit) {
 // correct.
 TEST(CommandCreatorTest, createDHCPDisable6) {
     // Create command with max-period value set to 20.
-    ConstElementPtr command = CommandCreator::createDHCPDisable(20, HAServerType::DHCPv6);
+    ConstElementPtr command = CommandCreator::createDHCPDisable(NetworkState::HA_REMOTE_COMMAND+2, 20,
+                                                                HAServerType::DHCPv6);
     ConstElementPtr arguments;
     ASSERT_NO_FATAL_FAILURE(testCommandBasics(command, "dhcp-disable", "dhcp6",
                                               arguments));
@@ -292,35 +309,40 @@ TEST(CommandCreatorTest, createDHCPDisable6) {
     EXPECT_EQ(20, max_period->intValue());
     ConstElementPtr origin = arguments->get("origin");
     ASSERT_TRUE(origin);
-    ASSERT_EQ("ha-partner", origin->stringValue());
+    ASSERT_EQ(NetworkState::HA_REMOTE_COMMAND+2, origin->intValue());
 
     // Repeat the test but this time the max-period is not specified.
-    command = CommandCreator::createDHCPDisable(0, HAServerType::DHCPv6);
+    command = CommandCreator::createDHCPDisable(NetworkState::HA_REMOTE_COMMAND+2, 0, HAServerType::DHCPv6);
     ASSERT_NO_FATAL_FAILURE(testCommandBasics(command, "dhcp-disable", "dhcp6",
                                               arguments));
     ASSERT_EQ(1, arguments->size());
     origin = arguments->get("origin");
     ASSERT_TRUE(origin);
-    ASSERT_EQ("ha-partner", origin->stringValue());
+    ASSERT_EQ(NetworkState::HA_REMOTE_COMMAND+2, origin->intValue());
 }
 
 // This test verifies that the dhcp-enable command (DHCPv6 case) is
 // correct.
 TEST(CommandCreatorTest, createDHCPEnable6) {
     ConstElementPtr arguments;
-    ConstElementPtr command = CommandCreator::createDHCPEnable(HAServerType::DHCPv6);
+    ConstElementPtr command = CommandCreator::createDHCPEnable(NetworkState::HA_REMOTE_COMMAND+2, HAServerType::DHCPv6);
     ASSERT_NO_FATAL_FAILURE(testCommandBasics(command, "dhcp-enable", "dhcp6",
                                               arguments));
     ASSERT_EQ(1, arguments->size());
     ConstElementPtr origin = arguments->get("origin");
     ASSERT_TRUE(origin);
-    ASSERT_EQ("ha-partner", origin->stringValue());
+    ASSERT_EQ(NetworkState::HA_REMOTE_COMMAND+2, origin->intValue());
 }
 
 // This test verifies that the ha-reset command sent to DHCPv6 server is correct.
 TEST(CommandCreatorTest, createHAReset6) {
-    ConstElementPtr command = CommandCreator::createHAReset(HAServerType::DHCPv6);
-    ASSERT_NO_FATAL_FAILURE(testCommandBasics(command, "ha-reset", "dhcp6"));
+    ConstElementPtr arguments;
+    ConstElementPtr command = CommandCreator::createHAReset("server1", HAServerType::DHCPv6);
+    ASSERT_NO_FATAL_FAILURE(testCommandBasics(command, "ha-reset", "dhcp6", arguments));
+    auto server_name = arguments->get("server-name");
+    ASSERT_TRUE(server_name);
+    ASSERT_EQ(Element::string, server_name->getType());
+    EXPECT_EQ("server1", server_name->stringValue());
 }
 
 // This test verifies that the command generated for the lease update
@@ -334,6 +356,7 @@ TEST(CommandCreatorTest, createLease6Update) {
     // The lease update must contain the "force-create" parameter indicating that
     // the lease must be created if it doesn't exist.
     lease_as_json->set("force-create", Element::create(true));
+    lease_as_json->set("origin", Element::create("ha-partner"));
     EXPECT_EQ(lease_as_json->str(), arguments->str());
 }
 
@@ -345,6 +368,7 @@ TEST(CommandCreatorTest, createLease6Delete) {
     ASSERT_NO_FATAL_FAILURE(testCommandBasics(command, "lease6-del", "dhcp6",
                                               arguments));
     ElementPtr lease_as_json = leaseAsJson(createLease6());
+    lease_as_json->set("origin", Element::create("ha-partner"));
     EXPECT_EQ(lease_as_json->str(), arguments->str());
 }
 
@@ -364,6 +388,10 @@ TEST(CommandCreatorTest, createLease6BulkApply) {
     ASSERT_NO_FATAL_FAILURE(testCommandBasics(command, "lease6-bulk-apply",
                                               "dhcp6", arguments));
 
+    ConstElementPtr origin = arguments->get("origin");
+    ASSERT_TRUE(origin);
+    ASSERT_EQ("ha-partner", origin->stringValue());
+
     // Verify deleted-leases.
     auto deleted_leases_json = arguments->get("deleted-leases");
     ASSERT_TRUE(deleted_leases_json);
@@ -396,6 +424,10 @@ TEST(CommandCreatorTest, createLease6BulkApplyFromBacklog) {
     ASSERT_NO_FATAL_FAILURE(testCommandBasics(command, "lease6-bulk-apply",
                                               "dhcp6", arguments));
 
+    ConstElementPtr origin = arguments->get("origin");
+    ASSERT_TRUE(origin);
+    ASSERT_EQ("ha-partner", origin->stringValue());
+
     // Verify deleted-leases.
     auto deleted_leases_json = arguments->get("deleted-leases");
     ASSERT_TRUE(deleted_leases_json);
@@ -475,7 +507,7 @@ TEST(CommandCreatorTest, createLease6GetPageZeroLimit) {
 // This test verifies that the ha-maintenance-notify command is correct
 // while being sent to the DHCPv4 server.
 TEST(CommandCreatorTest, createMaintenanceNotify4) {
-    ConstElementPtr command = CommandCreator::createMaintenanceNotify(true, HAServerType::DHCPv4);
+    ConstElementPtr command = CommandCreator::createMaintenanceNotify("server1", true, HAServerType::DHCPv4);
     ConstElementPtr arguments;
     ASSERT_NO_FATAL_FAILURE(testCommandBasics(command, "ha-maintenance-notify", "dhcp4",
                                               arguments));
@@ -489,7 +521,7 @@ TEST(CommandCreatorTest, createMaintenanceNotify4) {
 // This test verifies that the ha-maintenance-notify command is correct
 // while being sent to the DHCPv6 server.
 TEST(CommandCreatorTest, createMaintenanceNotify6) {
-    ConstElementPtr command = CommandCreator::createMaintenanceNotify(false, HAServerType::DHCPv6);
+    ConstElementPtr command = CommandCreator::createMaintenanceNotify("server1", false, HAServerType::DHCPv6);
     ConstElementPtr arguments;
     ASSERT_NO_FATAL_FAILURE(testCommandBasics(command, "ha-maintenance-notify", "dhcp6",
                                               arguments));
@@ -500,4 +532,36 @@ TEST(CommandCreatorTest, createMaintenanceNotify6) {
     EXPECT_FALSE(cancel->boolValue());
 }
 
+// This test verifies that the ha-sync-complete-notify command sent to a
+// DHCPv4 server is correct.
+TEST(CommandCreatorTest, createSyncCompleteNotify4) {
+    ConstElementPtr command = CommandCreator::createSyncCompleteNotify(1, "server1", HAServerType::DHCPv4);
+    ConstElementPtr arguments;
+    ASSERT_NO_FATAL_FAILURE(testCommandBasics(command, "ha-sync-complete-notify", "dhcp4", arguments));
+    auto server_name = arguments->get("server-name");
+    ASSERT_TRUE(server_name);
+    ASSERT_EQ(Element::string, server_name->getType());
+    EXPECT_EQ("server1", server_name->stringValue());
+    auto origin = arguments->get("origin");
+    ASSERT_TRUE(origin);
+    EXPECT_EQ(Element::integer, origin->getType());
+    EXPECT_EQ(1, origin->intValue());
+}
+
+// This test verifies that the ha-sync-complete-notify command sent to a
+// DHCPv6 server is correct.
+TEST(CommandCreatorTest, createSyncCompleteNotify6) {
+    ConstElementPtr command = CommandCreator::createSyncCompleteNotify(1, "server1", HAServerType::DHCPv6);
+    ConstElementPtr arguments;
+    ASSERT_NO_FATAL_FAILURE(testCommandBasics(command, "ha-sync-complete-notify", "dhcp6", arguments));
+    auto server_name = arguments->get("server-name");
+    ASSERT_TRUE(server_name);
+    ASSERT_EQ(Element::string, server_name->getType());
+    EXPECT_EQ("server1", server_name->stringValue());
+    auto origin = arguments->get("origin");
+    ASSERT_TRUE(origin);
+    EXPECT_EQ(Element::integer, origin->getType());
+    EXPECT_EQ(1, origin->intValue());
+}
+
 }
