@@ -1,10 +1,11 @@
-// Copyright (C) 2011-2021 Internet Systems Consortium, Inc. ("ISC")
+// Copyright (C) 2011-2022 Internet Systems Consortium, Inc. ("ISC")
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
 // file, You can obtain one at http://mozilla.org/MPL/2.0/.
 
 #include <config.h>
+
 #include <asiolink/asio_wrapper.h>
 #include <asiolink/io_service.h>
 
@@ -16,29 +17,6 @@
 namespace isc {
 namespace asiolink {
 
-namespace {
-// A trivial wrapper for std::function.  SunStudio doesn't seem to be capable
-// of handling a std::function object if directly passed to
-// io_service::post().
-class CallbackWrapper {
-public:
-
-    /// \brief Constructor
-    CallbackWrapper(const std::function<void()>& callback) :
-        callback_(callback) {}
-
-    /// \brief Function operator
-    void operator()() {
-        callback_();
-    }
-
-private:
-
-    /// \brief The callback function
-    std::function<void()> callback_;
-};
-}
-
 class IOServiceImpl {
 private:
     IOServiceImpl(const IOService& source);
@@ -67,16 +45,30 @@ public:
     /// This method return control to the caller as soon as the
     /// first handler has completed.  (If no handlers are ready when
     /// it is run, it will block until one is.)
-    void run_one() {
-        io_service_.run_one();
+    ///
+    /// \return The number of handlers that were executed.
+    size_t runOne() {
+        return (static_cast<size_t>(io_service_.run_one()));
     };
 
     /// \brief Run the underlying event loop for a ready events.
     ///
     /// This method executes handlers for all ready events and returns.
     /// It will return immediately if there are no ready events.
-    void poll() {
-        io_service_.poll();
+    ///
+    /// \return The number of handlers that were executed.
+    size_t poll() {
+        return (static_cast<size_t>(io_service_.poll()));
+    };
+
+    /// \brief Run the underlying event loop for a ready events.
+    ///
+    /// This method executes handlers for all ready events and returns.
+    /// It will return immediately if there are no ready events.
+    ///
+    /// \return The number of handlers that were executed.
+    size_t pollOne() {
+        return (static_cast<size_t>(io_service_.poll_one()));
     };
 
     /// \brief Stop the underlying event loop.
@@ -110,7 +102,7 @@ public:
     /// that share the same \c io_service with the authoritative server.
     /// It will eventually be removed once the wrapper interface is
     /// generalized.
-    boost::asio::io_service& get_io_service() {
+    boost::asio::io_service& getInternalIOService() {
         return (io_service_);
     }
 
@@ -118,8 +110,7 @@ public:
     ///
     /// \param callback The callback to be run on the IO service.
     void post(const std::function<void ()>& callback) {
-        const CallbackWrapper wrapper(callback);
-        io_service_.post(wrapper);
+        io_service_.post(callback);
     }
 
 private:
@@ -138,14 +129,19 @@ IOService::run() {
     io_impl_->run();
 }
 
-void
-IOService::run_one() {
-    io_impl_->run_one();
+size_t
+IOService::runOne() {
+    return (io_impl_->runOne());
 }
 
-void
+size_t
 IOService::poll() {
-    io_impl_->poll();
+    return (io_impl_->poll());
+}
+
+size_t
+IOService::pollOne() {
+    return (io_impl_->pollOne());
 }
 
 void
@@ -169,8 +165,8 @@ IOService::stopWork() {
 }
 
 boost::asio::io_service&
-IOService::get_io_service() {
-    return (io_impl_->get_io_service());
+IOService::getInternalIOService() {
+    return (io_impl_->getInternalIOService());
 }
 
 void
