@@ -1,4 +1,4 @@
-// Copyright (C) 2012-2023 Internet Systems Consortium, Inc. ("ISC")
+// Copyright (C) 2012-2024 Internet Systems Consortium, Inc. ("ISC")
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -50,6 +50,7 @@ OptionDataTypeUtil::OptionDataTypeUtil() {
     data_types_["string"] = OPT_STRING_TYPE;
     data_types_["tuple"] = OPT_TUPLE_TYPE;
     data_types_["fqdn"] = OPT_FQDN_TYPE;
+    data_types_["internal"] = OPT_INTERNAL_TYPE;
     data_types_["record"] = OPT_RECORD_TYPE;
 
     data_type_names_[OPT_EMPTY_TYPE] = "empty";
@@ -68,6 +69,7 @@ OptionDataTypeUtil::OptionDataTypeUtil() {
     data_type_names_[OPT_STRING_TYPE] = "string";
     data_type_names_[OPT_TUPLE_TYPE] = "tuple";
     data_type_names_[OPT_FQDN_TYPE] = "fqdn";
+    data_type_names_[OPT_INTERNAL_TYPE] = "internal";
     data_type_names_[OPT_RECORD_TYPE] = "record";
     // The "unknown" data type is declared here so as
     // it can be returned by reference by a getDataTypeName
