@@ -1,4 +1,4 @@
-// Copyright (C) 2012-2023 Internet Systems Consortium, Inc. ("ISC")
+// Copyright (C) 2012-2024 Internet Systems Consortium, Inc. ("ISC")
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -10,8 +10,10 @@
 #include <dhcp/dhcp6.h>
 #include <dhcp/option4_addrlst.h>
 #include <dhcp/option4_client_fqdn.h>
+#include <dhcp/option4_dnr.h>
 #include <dhcp/option6_addrlst.h>
 #include <dhcp/option6_client_fqdn.h>
+#include <dhcp/option6_dnr.h>
 #include <dhcp/option6_ia.h>
 #include <dhcp/option6_iaaddr.h>
 #include <dhcp/option6_iaprefix.h>
@@ -22,6 +24,7 @@
 #include <dhcp/option_int.h>
 #include <dhcp/option_int_array.h>
 #include <dhcp/option_opaque_data_tuples.h>
+#include <dhcp/option_classless_static_route.h>
 #include <dhcp/option_string.h>
 #include <dhcp/option_vendor.h>
 #include <dhcp/option_vendor_class.h>
@@ -30,6 +33,7 @@
 #include <dns/name.h>
 #include <util/strutil.h>
 #include <boost/algorithm/string/classification.hpp>
+#include <boost/algorithm/string/join.hpp>
 #include <boost/algorithm/string/predicate.hpp>
 #include <boost/dynamic_bitset.hpp>
 #include <boost/make_shared.hpp>
@@ -179,9 +183,11 @@ OptionDefinition::addRecordField(const OptionDataType data_type) {
 }
 
 OptionPtr
-OptionDefinition::optionFactory(Option::Universe u, uint16_t type,
+OptionDefinition::optionFactory(Option::Universe u,
+                                uint16_t type,
                                 OptionBufferConstIter begin,
-                                OptionBufferConstIter end) const {
+                                OptionBufferConstIter end,
+                                bool convenient_notation) const {
 
     try {
         // Some of the options are represented by the specialized classes derived
@@ -190,7 +196,7 @@ OptionDefinition::optionFactory(Option::Universe u, uint16_t type,
         // type to be returned. Therefore, we first check that if we are dealing
         // with such an option. If the instance is returned we just exit at this
         // point. If not, we will search for a generic option type to return.
-        OptionPtr option = factorySpecialFormatOption(u, begin, end);
+        OptionPtr option = factorySpecialFormatOption(u, begin, end, convenient_notation);
         if (option) {
             return (option);
         }
@@ -204,6 +210,9 @@ OptionDefinition::optionFactory(Option::Universe u, uint16_t type,
             }
 
         case OPT_BINARY_TYPE:
+        // If this is Internal type, and it wasn't handled by factorySpecialFormatOption() before,
+        // let's treat it like normal Binary type.
+        case OPT_INTERNAL_TYPE:
             return (factoryGeneric(u, type, begin, end));
 
         case OPT_UINT8_TYPE:
@@ -303,6 +312,12 @@ OptionDefinition::optionFactory(Option::Universe u, uint16_t type,
             if (type_ != OPT_EMPTY_TYPE) {
                 isc_throw(InvalidOptionValue, "no option value specified");
             }
+        } else if (type_ == OPT_INTERNAL_TYPE) {
+            // If an Option of type Internal is configured using csv-format=true, it means it is
+            // convenient notation option config that needs special parsing. Let's treat it like
+            // String type. optionFactory() will be called with convenient_notation flag set to
+            // true, so that the factory will have a chance to handle it in a special way.
+            writeToBuffer(u, boost::algorithm::join(values, ","), OPT_STRING_TYPE, buf);
         } else {
             writeToBuffer(u, util::str::trim(values[0]), type_, buf);
         }
@@ -327,7 +342,7 @@ OptionDefinition::optionFactory(Option::Universe u, uint16_t type,
             }
         }
     }
-    return (optionFactory(u, type, buf.begin(), buf.end()));
+    return (optionFactory(u, type, buf.begin(), buf.end(), (type_ == OPT_INTERNAL_TYPE)));
 }
 
 void
@@ -399,6 +414,12 @@ OptionDefinition::validate() const {
                             << " an option record.";
                     break;
                 }
+                // Internal type is not allowed within a record.
+                if (*it == OPT_INTERNAL_TYPE) {
+                    err_str << "internal data type can't be stored as a field in"
+                            << " an option record.";
+                    break;
+                }
             }
             // If the array flag is set the last field is an array.
             if (err_str.str().empty() && array_type_) {
@@ -428,6 +449,10 @@ OptionDefinition::validate() const {
             err_str << "array of empty value is not"
                     << " a valid option definition.";
 
+        } else if (type_ == OPT_INTERNAL_TYPE) {
+            err_str << "array of internal type value is not"
+                    << " a valid option definition.";
+
         }
     }
 
@@ -821,7 +846,8 @@ OptionDefinition::factoryFqdnList(Option::Universe u,
 OptionPtr
 OptionDefinition::factorySpecialFormatOption(Option::Universe u,
                                              OptionBufferConstIter begin,
-                                             OptionBufferConstIter end) const {
+                                             OptionBufferConstIter end,
+                                             bool convenient_notation) const {
     if ((u == Option::V6) && haveSpace(DHCP6_OPTION_SPACE)) {
         switch (getCode()) {
         case D6O_IA_NA:
@@ -866,6 +892,9 @@ OptionDefinition::factorySpecialFormatOption(Option::Universe u,
             // Prefix Exclude (option code 67),
             return (OptionPtr(new Option6PDExclude(begin, end)));
 
+        case D6O_V6_DNR:
+            return (OptionPtr(new Option6Dnr(begin, end)));
+
         default:
             break;
         }
@@ -879,6 +908,9 @@ OptionDefinition::factorySpecialFormatOption(Option::Universe u,
             // Record of 3 uint8 and a FQDN, no array.
             return (OptionPtr(new Option4ClientFqdn(begin, end)));
 
+        case DHO_CLASSLESS_STATIC_ROUTE:
+            return (OptionPtr(new OptionClasslessStaticRoute(begin, end, convenient_notation)));
+
         case DHO_VIVCO_SUBOPTIONS:
             // Record of uint32 followed by binary.
             // V-I Vendor Class (option code 124).
@@ -894,6 +926,9 @@ OptionDefinition::factorySpecialFormatOption(Option::Universe u,
             // DHCPv4 SZTP Redirect Option (option code 143).
             return (factoryOpaqueDataTuples(Option::V4, getCode(), begin, end, OpaqueDataTuple::LENGTH_2_BYTES));
 
+        case DHO_V4_DNR:
+            return (OptionPtr(new Option4Dnr(begin, end)));
+
         default:
             break;
         }
