@@ -1,4 +1,4 @@
-// Copyright (C) 2015-2017 Internet Systems Consortium, Inc. ("ISC")
+// Copyright (C) 2015-2023 Internet Systems Consortium, Inc. ("ISC")
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -7,7 +7,7 @@
 #include <config.h>
 #include <dhcp/dhcp4.h>
 #include <dhcp/duid_factory.h>
-#include <dhcp/tests/iface_mgr_test_config.h>
+#include <dhcp/testutils/iface_mgr_test_config.h>
 #include <testutils/io_utils.h>
 #include <util/encode/hex.h>
 #include <util/range_utilities.h>
@@ -356,7 +356,7 @@ TEST_F(DUIDFactoryTest, createLLTExplicitLinkLayerAddress) {
 
 // This test verifies that the factory function creates DUID-LLT from
 // all values explicitly specified.
-TEST_F(DUIDFactoryTest, createLLTAllExplcitParameters) {
+TEST_F(DUIDFactoryTest, createLLTAllExplicitParameters) {
     ASSERT_NO_THROW(factory().createLLT(HTYPE_FDDI, 0xFAFAFAFA,
                                         toVector("24242424242424242424")));
     testLLT("0008", "FAFAFAFA", true, "24242424242424242424");
