@@ -1,4 +1,4 @@
-// Copyright (C) 2014-2020 Internet Systems Consortium, Inc. ("ISC")
+// Copyright (C) 2014-2024 Internet Systems Consortium, Inc. ("ISC")
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -148,7 +148,7 @@ public:
     /// @param client_n  N Flag from the client's FQDN
     /// @param server_s [out] S Flag for the server's FQDN
     /// @param server_n [out] N Flag for the server's FQDN
-    /// @param ddns_params DDNS behaviorial configuration parameters
+    /// @param ddns_params DDNS behavioral configuration parameters
     ///
     /// @throw isc::BadValue if client_s and client_n are both 1 as this is
     /// an invalid combination per RFCs.
@@ -168,7 +168,7 @@ public:
     /// ('.' for IPv4 or ':' for IPv6) replaced with a hyphen, '-'.
     ///
     /// @param address IP address from which to derive the name (IPv4 or IPv6)
-    /// @param ddns_params DDNS behaviorial configuration parameters
+    /// @param ddns_params DDNS behavioral configuration parameters
     /// @param trailing_dot A boolean value which indicates whether trailing
     /// dot should be appended (if true) or not (false).
     ///
@@ -184,8 +184,11 @@ public:
     ///
     ///     <partial_name>.<qualifying-suffix>.
     ///
+    /// Note that the qualifying suffix will only be appended if the
+    /// input name does not already end with that suffix.
+    ///
     /// @param partial_name domain name to qualify
-    /// @param ddns_params DDNS behaviorial configuration parameters
+    /// @param ddns_params DDNS behavioral configuration parameters
     /// @param trailing_dot A boolean value which when true guarantees the
     /// result will end with a "." and when false that the result will not
     /// end with a "."   Note that this rule is applied even if the qualifying
@@ -205,7 +208,7 @@ public:
     ///
     /// @param fqdn FQDN option from which to read client (inbound) flags
     /// @param fqdn_resp FQDN option to update with the server (outbound) flags
-    /// @param ddns_params DDNS behaviorial configuration parameters
+    /// @param ddns_params DDNS behavioral configuration parameters
     /// @tparam T FQDN Option class containing the FQDN data such as
     /// dhcp::Option4ClientFqdn or dhcp::Option6ClientFqdn
     template <class T>
@@ -256,7 +259,7 @@ public:
     ///
     /// @param fqdn FQDN option from which to get client (inbound) name
     /// @param fqdn_resp FQDN option to update with the adjusted name
-    /// @param ddns_params DDNS behaviorial configuration parameters
+    /// @param ddns_params DDNS behavioral configuration parameters
     /// @tparam T  FQDN Option class containing the FQDN data such as
     /// dhcp::Option4ClientFqdn or dhcp::Option6ClientFqdn
     template <class T>
@@ -276,8 +279,8 @@ public:
     /// @param io_service IOService to be used for sender IO event processing
     /// @warning It is up to the invoking layer to ensure the io_service
     /// instance used outlives the D2ClientMgr send mode. When the send mode
-    /// is exited, either explicitly by callind stopSender() or implicitly
-    /// through D2CLientMgr destruction, any ASIO objects such as sockets or
+    /// is exited, either explicitly by calling stopSender() or implicitly
+    /// through D2ClientMgr destruction, any ASIO objects such as sockets or
     /// timers will be closed and released.  If the io_service goes out of scope
     /// first this behavior could be unpredictable.
     ///
@@ -496,12 +499,15 @@ D2ClientMgr::adjustDomainName(const T& fqdn, T& fqdn_resp, const DdnsParams& ddn
             std::vector<std::string> labels;
             boost::algorithm::split(labels, raw_name, boost::is_any_of("."));
             std::stringstream ss;
-            for (auto label = labels.begin(); label != labels.end(); ++label ) {
-                if (label != labels.begin()) {
+            bool first = true;
+            for (auto const& label : labels) {
+                if (!first) {
                     ss << ".";
+                } else {
+                    first = false;
                 }
 
-                ss << sanitizer->scrub(*label);
+                ss << sanitizer->scrub(label);
             }
 
             client_name = ss.str();
@@ -510,8 +516,7 @@ D2ClientMgr::adjustDomainName(const T& fqdn, T& fqdn_resp, const DdnsParams& ddn
         // If the supplied name is partial, qualify it by adding the suffix.
         if (fqdn.getDomainNameType() == T::PARTIAL) {
             fqdn_resp.setDomainName(qualifyName(client_name, ddns_params, true), T::FULL);
-        }
-        else  {
+        } else  {
             fqdn_resp.setDomainName(client_name, T::FULL);
         }
     }
