@@ -1,4 +1,4 @@
-// Copyright (C) 2012-2023 Internet Systems Consortium, Inc. ("ISC")
+// Copyright (C) 2012-2024 Internet Systems Consortium, Inc. ("ISC")
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -15,7 +15,6 @@
 #include <stats/stats_mgr.h>
 #include <util/encode/hex.h>
 
-#include <boost/foreach.hpp>
 #include <boost/algorithm/string.hpp>
 
 #include <algorithm>
@@ -38,8 +37,6 @@ using namespace std;
 namespace isc {
 namespace dhcp {
 
-IOServicePtr LeaseMgr::io_service_ = IOServicePtr();
-
 LeasePageSize::LeasePageSize(const size_t page_size)
     : page_size_(page_size) {
 
@@ -108,9 +105,8 @@ LeaseMgr::recountLeaseStats4() {
     const Subnet4Collection* subnets =
         CfgMgr::instance().getCurrentCfg()->getCfgSubnets4()->getAll();
 
-    for (Subnet4Collection::const_iterator subnet = subnets->begin();
-         subnet != subnets->end(); ++subnet) {
-        SubnetID subnet_id = (*subnet)->getID();
+    for (auto const& subnet : *subnets) {
+        SubnetID subnet_id = subnet->getID();
         stats_mgr.setValue(StatsMgr::generateName("subnet", subnet_id,
                                                   "assigned-addresses"),
                            zero);
@@ -131,7 +127,7 @@ LeaseMgr::recountLeaseStats4() {
             stats_mgr.setValue(name_rec, zero);
         }
 
-        for (const auto& pool : (*subnet)->getPools(Lease::TYPE_V4)) {
+        for (auto const& pool : subnet->getPools(Lease::TYPE_V4)) {
             const std::string name_aa(StatsMgr::generateName("subnet", subnet_id,
                                                              StatsMgr::generateName("pool", pool->getID(),
                                                                                     "assigned-addresses")));
@@ -322,9 +318,8 @@ LeaseMgr::recountLeaseStats6() {
     const Subnet6Collection* subnets =
         CfgMgr::instance().getCurrentCfg()->getCfgSubnets6()->getAll();
 
-    for (Subnet6Collection::const_iterator subnet = subnets->begin();
-         subnet != subnets->end(); ++subnet) {
-        SubnetID subnet_id = (*subnet)->getID();
+    for (auto const& subnet : *subnets) {
+        SubnetID subnet_id = subnet->getID();
         stats_mgr.setValue(StatsMgr::generateName("subnet", subnet_id,
                                                   "assigned-nas"),
                            zero);
@@ -355,7 +350,7 @@ LeaseMgr::recountLeaseStats6() {
                 zero);
         }
 
-        for (const auto& pool : (*subnet)->getPools(Lease::TYPE_NA)) {
+        for (auto const& pool : subnet->getPools(Lease::TYPE_NA)) {
             const std::string& name_anas(StatsMgr::generateName("subnet", subnet_id,
                                                                 StatsMgr::generateName("pool", pool->getID(),
                                                                                        "assigned-nas")));
@@ -385,7 +380,7 @@ LeaseMgr::recountLeaseStats6() {
             }
         }
 
-        for (const auto& pool : (*subnet)->getPools(Lease::TYPE_PD)) {
+        for (auto const& pool : subnet->getPools(Lease::TYPE_PD)) {
             const std::string& name_apds(StatsMgr::generateName("subnet", subnet_id,
                                                                 StatsMgr::generateName("pd-pool", pool->getID(),
                                                                                        "assigned-pds")));
@@ -724,7 +719,7 @@ LeaseMgr::upgradeLease4ExtendedInfo(const Lease4Ptr& lease,
         }
 
         verifying = "relay-agent-info";
-        for (auto elem : extended_info->mapValue()) {
+        for (auto const& elem : extended_info->mapValue()) {
             if ((elem.first != "sub-options") &&
                 (elem.first != "remote-id") &&
                 (elem.first != "relay-id") &&
@@ -1062,7 +1057,7 @@ LeaseMgr::upgradeLease6ExtendedInfo(const Lease6Ptr& lease,
             }
 
             verifying = (upgraded ? "relays" : "relay-info");
-            for (auto elem : relay->mapValue()) {
+            for (auto const& elem : relay->mapValue()) {
                 if ((elem.first != "hop") &&
                     (elem.first != "link") &&
                     (elem.first != "peer") &&
