@@ -1,4 +1,4 @@
-// Copyright (C) 2012-2025 Internet Systems Consortium, Inc. ("ISC")
+// Copyright (C) 2012-2024 Internet Systems Consortium, Inc. ("ISC")
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -17,7 +17,6 @@
 #endif
 
 #include <boost/algorithm/string.hpp>
-#include <boost/foreach.hpp>
 
 #include <algorithm>
 #include <iostream>
@@ -79,15 +78,9 @@ LeaseMgrFactory::create(const std::string& dbaccess) {
 #endif
     }
     if (parameters[type] == string("memfile")) {
-        try {
-            LOG_INFO(dhcpsrv_logger, DHCPSRV_MEMFILE_DB).arg(redacted);
-            getLeaseMgrPtr().reset(new Memfile_LeaseMgr(parameters));
-            return;
-        } catch (const std::exception& ex) {
-            LOG_ERROR(dhcpsrv_logger, DHCPSRV_MEMFILE_FAILED_TO_OPEN)
-                .arg(ex.what());
-            throw;
-        }
+        LOG_INFO(dhcpsrv_logger, DHCPSRV_MEMFILE_DB).arg(redacted);
+        getLeaseMgrPtr().reset(new Memfile_LeaseMgr(parameters));
+        return;
     }
 
     // Get here on no match
