@@ -1,4 +1,4 @@
-// Copyright (C) 2012-2023 Internet Systems Consortium, Inc. ("ISC")
+// Copyright (C) 2012-2024 Internet Systems Consortium, Inc. ("ISC")
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -23,14 +23,16 @@
 #include <dhcpsrv/shared_network.h>
 #include <dhcpsrv/subnet.h>
 #include <exceptions/exceptions.h>
+#include <testutils/log_utils.h>
 
 #include <boost/pointer_cast.hpp>
 
 #include <gtest/gtest.h>
 
 using namespace isc;
-using namespace isc::dhcp;
 using namespace isc::asiolink;
+using namespace isc::dhcp;
+using namespace isc::dhcp::test;
 using namespace isc::util;
 
 namespace {
@@ -39,9 +41,11 @@ TEST(Subnet4Test, constructor) {
     EXPECT_NO_THROW(Subnet4 subnet1(IOAddress("192.0.2.2"), 16,
                                     1, 2, 3, 10));
 
-    EXPECT_THROW(Subnet4 subnet2(IOAddress("192.0.2.0"), 33, 1, 2, 3),
+    EXPECT_THROW(Subnet4 subnet2(IOAddress("192.0.2.0"),
+                                 33, 1, 2, 3, SubnetID(2)),
                 BadValue); // invalid prefix length
-    EXPECT_THROW(Subnet4 subnet3(IOAddress("2001:db8::1"), 24, 1, 2, 3),
+    EXPECT_THROW(Subnet4 subnet3(IOAddress("2001:db8::1"),
+                                 24, 1, 2, 3, SubnetID(3)),
                 BadValue); // IPv6 addresses are not allowed in Subnet4
 }
 
@@ -65,7 +69,8 @@ TEST(Subnet4Test, defaults) {
     Triplet<uint32_t> t1;
     Triplet<uint32_t> t2;
     Triplet<uint32_t> valid_lft;
-    Subnet4 subnet(IOAddress("192.0.2.0"), 24, t1, t2, valid_lft);
+    Subnet4 subnet(IOAddress("192.0.2.0"), 24,
+                   t1, t2, valid_lft, SubnetID(10));
 
     EXPECT_TRUE(subnet.getIface().unspecified());
     EXPECT_TRUE(subnet.getIface().empty());
@@ -155,33 +160,8 @@ TEST(Subnet4Test, defaults) {
     EXPECT_EQ(0, subnet.getOfferLft().get());
 }
 
-// Checks that the subnet id can be either autogenerated or set to an
-// arbitrary value through the constructor.
-TEST(Subnet4Test, subnetID) {
-    // Create subnet and don't specify id, so as it is autogenerated.
-    auto subnet = Subnet4::create(IOAddress("192.0.2.0"), 24, 1000, 2000,
-                                  3000);
-    SubnetID id0 = subnet->getID();
-
-    // Create another subnet and let id be autogenerated.
-    subnet.reset(new Subnet4(IOAddress("192.0.3.0"), 24, 1000, 2000,
-                             3000));
-    SubnetID id1 = subnet->getID();
-
-    // The autogenerated ids must not be equal.
-    EXPECT_NE(id0, id1);
-
-    // Create third subnet but this time select an arbitrary id. The id
-    // we use the one of the second subnet. That way we ensure that the
-    // subnet id we provide via constructor is used and it is not
-    // autogenerated - if it was autogenerated we would get id other
-    // than id1 because id1 has already been used.
-    subnet = Subnet4::create(IOAddress("192.0.4.0"), 24, 1000, 2000, 3000, id1);
-    EXPECT_EQ(id1, subnet->getID());
-}
-
 TEST(Subnet4Test, inRange) {
-    Subnet4 subnet(IOAddress("192.0.2.1"), 24, 1000, 2000, 3000);
+  Subnet4 subnet(IOAddress("192.0.2.1"), 24, 1000, 2000, 3000, SubnetID(1));
 
     EXPECT_EQ(1000, subnet.getT1().get());
     EXPECT_EQ(2000, subnet.getT2().get());
@@ -201,7 +181,7 @@ TEST(Subnet4Test, inRange) {
 // Checks whether the relay list is empty by default
 // and basic operations function
 TEST(Subnet4Test, relay) {
-    Subnet4 subnet(IOAddress("192.0.2.1"), 24, 1000, 2000, 3000);
+    Subnet4 subnet(IOAddress("192.0.2.1"), 24, 1000, 2000, 3000, SubnetID(1));
 
     // Should be empty.
     EXPECT_FALSE(subnet.hasRelays());
@@ -230,7 +210,7 @@ TEST(Subnet4Test, relay) {
 
 // Checks whether siaddr field can be set and retrieved correctly.
 TEST(Subnet4Test, siaddr) {
-    Subnet4 subnet(IOAddress("192.0.2.1"), 24, 1000, 2000, 3000);
+    Subnet4 subnet(IOAddress("192.0.2.1"), 24, 1000, 2000, 3000, SubnetID(1));
 
     // Check if the default is 0.0.0.0
     EXPECT_EQ("0.0.0.0", subnet.getSiaddr().get().toText());
@@ -248,7 +228,7 @@ TEST(Subnet4Test, siaddr) {
 
 // Checks whether server-hostname field can be set and retrieved correctly.
 TEST(Subnet4Test, serverHostname) {
-    Subnet4 subnet(IOAddress("192.0.2.1"), 24, 1000, 2000, 3000);
+    Subnet4 subnet(IOAddress("192.0.2.1"), 24, 1000, 2000, 3000, SubnetID(1));
 
     // Check if the default is empty
     EXPECT_TRUE(subnet.getSname().empty());
@@ -262,7 +242,7 @@ TEST(Subnet4Test, serverHostname) {
 
 // Checks whether boot-file-name field can be set and retrieved correctly.
 TEST(Subnet4Test, bootFileName) {
-    Subnet4 subnet(IOAddress("192.0.2.1"), 24, 1000, 2000, 3000);
+    Subnet4 subnet(IOAddress("192.0.2.1"), 24, 1000, 2000, 3000, SubnetID(1));
 
     // Check if the default is empty
     EXPECT_TRUE(subnet.getFilename().empty());
@@ -276,7 +256,7 @@ TEST(Subnet4Test, bootFileName) {
 
 // Checks if the match-client-id flag can be set and retrieved.
 TEST(Subnet4Test, matchClientId) {
-    Subnet4 subnet(IOAddress("192.0.2.1"), 24, 1000, 2000, 3000);
+    Subnet4 subnet(IOAddress("192.0.2.1"), 24, 1000, 2000, 3000, SubnetID(1));
 
     // By default the flag should be set to true.
     EXPECT_TRUE(subnet.getMatchClientId());
@@ -293,7 +273,8 @@ TEST(Subnet4Test, matchClientId) {
 // Checks that it is possible to add and retrieve multiple pools.
 TEST(Subnet4Test, pool4InSubnet4) {
 
-    auto subnet = Subnet4::create(IOAddress("192.1.2.0"), 24, 1, 2, 3);
+    auto subnet = Subnet4::create(IOAddress("192.1.2.0"),
+                                  24, 1, 2, 3, SubnetID(1));
 
     PoolPtr pool1(new Pool4(IOAddress("192.1.2.0"), 25));
     PoolPtr pool2(new Pool4(IOAddress("192.1.2.128"), 26));
@@ -402,7 +383,8 @@ TEST(Subnet4Test, pool4InSubnet4) {
 TEST(Subnet4Test, getCapacity) {
 
     // There's one /24 pool.
-    auto subnet = Subnet4::create(IOAddress("192.1.2.0"), 24, 1, 2, 3);
+    auto subnet = Subnet4::create(IOAddress("192.1.2.0"),
+                                  24, 1, 2, 3, SubnetID(1));
 
     // There are no pools defined, so the total number of available addrs is 0.
     EXPECT_EQ(0, subnet->getPoolCapacity(Lease::TYPE_V4));
@@ -458,7 +440,8 @@ TEST(Subnet4Test, getCapacity) {
 // Checks that it is not allowed to add invalid pools.
 TEST(Subnet4Test, pool4Checks) {
 
-    auto subnet = Subnet4::create(IOAddress("192.0.2.0"), 8, 1, 2, 3);
+    auto subnet = Subnet4::create(IOAddress("192.0.2.0"),
+                                  8, 1, 2, 3, SubnetID(1));
 
     // this one is in subnet
     Pool4Ptr pool1(new Pool4(IOAddress("192.254.0.0"), 16));
@@ -524,7 +507,8 @@ TEST(Subnet4Test, pool4Checks) {
 // information about allowed client class (a single class).
 TEST(Subnet4Test, clientClass) {
     // Create the V4 subnet.
-    auto subnet = Subnet4::create(IOAddress("192.0.2.0"), 8, 1, 2, 3);
+    auto subnet = Subnet4::create(IOAddress("192.0.2.0"),
+                                  8, 1, 2, 3, SubnetID(1));
 
     // This client does not belong to any class.
     isc::dhcp::ClientClasses no_class;
@@ -583,7 +567,8 @@ TEST(Subnet4Test, clientClass) {
 
 TEST(Subnet4Test, addInvalidOption) {
     // Create the V4 subnet.
-    auto subnet = Subnet4::create(IOAddress("192.0.2.0"), 8, 1, 2, 3);
+    auto subnet = Subnet4::create(IOAddress("192.0.2.0"),
+                                  8, 1, 2, 3, SubnetID(1));
 
     // Create NULL pointer option. Attempt to add NULL option
     // should result in exception.
@@ -596,7 +581,8 @@ TEST(Subnet4Test, addInvalidOption) {
 
 // This test verifies that inRange() and inPool() methods work properly.
 TEST(Subnet4Test, inRangeinPool) {
-    auto subnet = Subnet4::create(IOAddress("192.0.0.0"), 8, 1, 2, 3);
+    auto subnet = Subnet4::create(IOAddress("192.0.0.0"),
+                                  8, 1, 2, 3, SubnetID(1));
 
     // this one is in subnet
     Pool4Ptr pool1(new Pool4(IOAddress("192.2.0.0"), 16));
@@ -656,7 +642,8 @@ TEST(Subnet4Test, inRangeinPool) {
 
 // This test checks if the toText() method returns text representation
 TEST(Subnet4Test, toText) {
-    auto subnet = Subnet4::create(IOAddress("192.0.2.0"), 24, 1, 2, 3);
+    auto subnet = Subnet4::create(IOAddress("192.0.2.0"),
+                                  24, 1, 2, 3, SubnetID(1));
     EXPECT_EQ("192.0.2.0/24", subnet->toText());
 }
 
@@ -691,7 +678,8 @@ TEST(Subnet4Test, parsePrefix) {
 
 // This test checks if the get() method returns proper parameters
 TEST(Subnet4Test, get) {
-    auto subnet = Subnet4::create(IOAddress("192.0.2.0"), 28, 1, 2, 3);
+    auto subnet = Subnet4::create(IOAddress("192.0.2.0"),
+                                  28, 1, 2, 3, SubnetID(1));
     EXPECT_EQ("192.0.2.0", subnet->get().first.toText());
     EXPECT_EQ(28, subnet->get().second);
 }
@@ -700,7 +688,8 @@ TEST(Subnet4Test, get) {
 // is working properly.
 TEST(Subnet4Test, PoolType) {
 
-    auto subnet = Subnet4::create(IOAddress("192.2.0.0"), 16, 1, 2, 3);
+    auto subnet = Subnet4::create(IOAddress("192.2.0.0"),
+                                  16, 1, 2, 3, SubnetID(1));
 
     PoolPtr pool1(new Pool4(IOAddress("192.2.1.0"), 24));
     PoolPtr pool2(new Pool4(IOAddress("192.2.2.0"), 24));
@@ -746,7 +735,7 @@ TEST(Subnet4Test, PoolType) {
 // called.
 TEST(Subnet4Test, getServerId) {
     // Initially, the subnet has no server identifier.
-    Subnet4 subnet(IOAddress("192.2.0.0"), 16, 1, 2, 3);
+    Subnet4 subnet(IOAddress("192.2.0.0"), 16, 1, 2, 3, SubnetID(1));
     EXPECT_TRUE(subnet.getServerId().isV4Zero());
 
     // Add server identifier.
@@ -768,7 +757,8 @@ TEST(Subnet4Test, getServerId) {
 // states are instantiated for a subnet.
 TEST(Subnet4Test, createAllocatorsIterative) {
     // Create a subnet.
-    auto subnet = Subnet4::create(IOAddress("192.2.0.0"), 16, 1, 2, 3);
+    auto subnet = Subnet4::create(IOAddress("192.2.0.0"),
+                                  16, 1, 2, 3, SubnetID(1));
     ASSERT_TRUE(subnet);
     // Create a pool.
     auto pool = boost::make_shared<Pool4>(IOAddress("192.2.0.0"), 16);
@@ -790,7 +780,8 @@ TEST(Subnet4Test, createAllocatorsIterative) {
 // states are instantiated for a subnet.
 TEST(Subnet4Test, createAllocatorsRandom) {
     // Create a subnet.
-    auto subnet = Subnet4::create(IOAddress("192.2.0.0"), 16, 1, 2, 3);
+    auto subnet = Subnet4::create(IOAddress("192.2.0.0"),
+                                  16, 1, 2, 3, SubnetID(1));
     ASSERT_TRUE(subnet);
     // Create a pool.
     auto pool = boost::make_shared<Pool4>(IOAddress("192.2.0.0"), 16);
@@ -813,7 +804,8 @@ TEST(Subnet4Test, createAllocatorsRandom) {
 // states are instantiated for a subnet.
 TEST(Subnet4Test, createAllocatorsFreeLeaseQueue) {
     // Create a subnet.
-    auto subnet = Subnet4::create(IOAddress("192.2.0.0"), 16, 1, 2, 3);
+    auto subnet = Subnet4::create(IOAddress("192.2.0.0"),
+                                  16, 1, 2, 3, SubnetID(1));
     ASSERT_TRUE(subnet);
     // Create a pool.
     auto pool = boost::make_shared<Pool4>(IOAddress("192.2.0.0"), 16);
@@ -837,11 +829,13 @@ TEST(Subnet4Test, createAllocatorsFreeLeaseQueue) {
 TEST(Subnet6Test, constructor) {
 
     EXPECT_NO_THROW(Subnet6 subnet1(IOAddress("2001:db8:1::"), 64,
-                                    1, 2, 3, 4));
+                                    1, 2, 3, 4, SubnetID(1)));
 
-    EXPECT_THROW(Subnet6 subnet2(IOAddress("2001:db8:1::"), 129, 1, 2, 3, 4),
+    EXPECT_THROW(Subnet6 subnet2(IOAddress("2001:db8:1::"),
+                                 129, 1, 2, 3, 4, SubnetID(2)),
                 BadValue); // invalid prefix length
-    EXPECT_THROW(Subnet6 subnet3(IOAddress("192.168.0.0"), 32, 1, 2, 3, 4),
+    EXPECT_THROW(Subnet6 subnet3(IOAddress("192.168.0.0"),
+                                 32, 1, 2, 3, 4, SubnetID(3)),
                 BadValue); // IPv4 addresses are not allowed in Subnet6
 }
 
@@ -868,7 +862,7 @@ TEST(SharedNetwork6Test, defaults) {
     Triplet<uint32_t> preferred_lft;
     Triplet<uint32_t> valid_lft;
     Subnet6 subnet(IOAddress("2001:db8:1::"), 64, t1, t2, preferred_lft,
-                   valid_lft);
+                   valid_lft, SubnetID(1));
 
     EXPECT_TRUE(subnet.getIface().unspecified());
     EXPECT_TRUE(subnet.getIface().empty());
@@ -937,34 +931,9 @@ TEST(SharedNetwork6Test, defaults) {
     EXPECT_FALSE(subnet.getDdnsUpdateOnRenew().get());
 }
 
-// Checks that the subnet id can be either autogenerated or set to an
-// arbitrary value through the constructor.
-TEST(Subnet6Test, subnetID) {
-    // Create subnet and don't specify id, so as it is autogenerated.
-    auto subnet = Subnet6::create(IOAddress("2001:db8:1::"), 64, 1000, 2000,
-                                  3000, 4000);
-    SubnetID id0 = subnet->getID();
-
-    // Create another subnet and let id be autogenerated.
-    subnet.reset(new Subnet6(IOAddress("2001:db8:2::"), 64, 1000, 2000,
-                             3000, 4000));
-    SubnetID id1 = subnet->getID();
-
-    // The autogenerated ids must not be equal.
-    EXPECT_NE(id0, id1);
-
-    // Create third subnet but this time select an arbitrary id. The id
-    // we use us the one of second subnet. That way we ensure that the
-    // subnet id we provide via constructor is used and it is not
-    // autogenerated - if it was autogenerated we would get id other
-    // than id1 because id1 has already been used.
-    subnet.reset(new Subnet6(IOAddress("2001:db8:3::"), 64, 1000, 2000,
-                             3000, 4000, id1));
-    EXPECT_EQ(id1, subnet->getID());
-}
-
 TEST(Subnet6Test, inRange) {
-    Subnet6 subnet(IOAddress("2001:db8:1::"), 64, 1000, 2000, 3000, 4000);
+    Subnet6 subnet(IOAddress("2001:db8:1::"),
+                   64, 1000, 2000, 3000, 4000, SubnetID(1));
 
     EXPECT_EQ(1000, subnet.getT1().get());
     EXPECT_EQ(2000, subnet.getT2().get());
@@ -972,7 +941,7 @@ TEST(Subnet6Test, inRange) {
     EXPECT_EQ(4000, subnet.getValid().get());
 
     EXPECT_FALSE(subnet.inRange(IOAddress("2001:db8:0:ffff:ffff:ffff:ffff:ffff")));
-    EXPECT_TRUE(subnet.inRange(IOAddress("2001:db8:1::0")));
+    EXPECT_TRUE(subnet.inRange(IOAddress("2001:db8:1::")));
     EXPECT_TRUE(subnet.inRange(IOAddress("2001:db8:1::1")));
     EXPECT_TRUE(subnet.inRange(IOAddress("2001:db8:1::ffff:ffff:ffff:ffff")));
     EXPECT_FALSE(subnet.inRange(IOAddress("2001:db8:1:1::")));
@@ -982,7 +951,8 @@ TEST(Subnet6Test, inRange) {
 // Checks whether the relay list is empty by default
 // and basic operations function
 TEST(Subnet6Test, relay) {
-    Subnet6 subnet(IOAddress("2001:db8:1::"), 64, 1000, 2000, 3000, 4000);
+    Subnet6 subnet(IOAddress("2001:db8:1::"),
+                   64, 1000, 2000, 3000, 4000, SubnetID(1));
 
     // Should be empty.
     EXPECT_FALSE(subnet.hasRelays());
@@ -1013,7 +983,8 @@ TEST(Subnet6Test, relay) {
 // calculated properly.
 TEST(Subnet6Test, Pool6getCapacity) {
 
-    auto subnet = Subnet6::create(IOAddress("2001:db8:1::"), 56, 1, 2, 3, 4);
+    auto subnet = Subnet6::create(IOAddress("2001:db8:1::"),
+                                  56, 1, 2, 3, 4, SubnetID(1));
 
     // There's 2^16 = 65536 addresses in this one.
     PoolPtr pool1(new Pool6(Lease::TYPE_NA, IOAddress("2001:db8:1:1::"), 112));
@@ -1072,7 +1043,8 @@ TEST(Subnet6Test, Pool6getCapacity) {
 // calculated properly.
 TEST(Subnet6Test, Pool6PdgetPoolCapacity) {
 
-    auto subnet = Subnet6::create(IOAddress("2001:db8::"), 32, 1, 2, 3, 4);
+    auto subnet = Subnet6::create(IOAddress("2001:db8::"),
+                                  32, 1, 2, 3, 4, SubnetID(1));
 
     // There's 2^16 = 65536 addresses in this one.
     PoolPtr pool1(new Pool6(Lease::TYPE_PD, IOAddress("2001:db8:1::"), 48, 64));
@@ -1109,7 +1081,8 @@ TEST(Subnet6Test, Pool6PdgetPoolCapacity) {
 
 TEST(Subnet6Test, Pool6InSubnet6) {
 
-    auto subnet = Subnet6::create(IOAddress("2001:db8:1::"), 56, 1, 2, 3, 4);
+    auto subnet = Subnet6::create(IOAddress("2001:db8:1::"),
+                                  56, 1, 2, 3, 4, SubnetID(1));
 
     PoolPtr pool1(new Pool6(Lease::TYPE_NA, IOAddress("2001:db8:1:1::"), 64));
     PoolPtr pool2(new Pool6(Lease::TYPE_NA, IOAddress("2001:db8:1:2::"), 64));
@@ -1174,7 +1147,8 @@ TEST(Subnet6Test, Pool6InSubnet6) {
 // Check if Subnet6 supports different types of pools properly.
 TEST(Subnet6Test, poolTypes) {
 
-    auto subnet = Subnet6::create(IOAddress("2001:db8:1::"), 56, 1, 2, 3, 4);
+    auto subnet = Subnet6::create(IOAddress("2001:db8:1::"),
+                                  56, 1, 2, 3, 4, SubnetID(1));
 
     PoolPtr pool1(new Pool6(Lease::TYPE_NA, IOAddress("2001:db8:1:1::"), 64));
     PoolPtr pool2(new Pool6(Lease::TYPE_TA, IOAddress("2001:db8:1:2::"), 64));
@@ -1246,7 +1220,8 @@ TEST(Subnet6Test, poolTypes) {
 // information about allowed client class (a single class).
 TEST(Subnet6Test, clientClass) {
     // Create the V6 subnet.
-    auto subnet = Subnet6::create(IOAddress("2001:db8:1::"), 56, 1, 2, 3, 4);
+    auto subnet = Subnet6::create(IOAddress("2001:db8:1::"),
+                                  56, 1, 2, 3, 4, SubnetID(1));
 
     // This client does not belong to any class.
     isc::dhcp::ClientClasses no_class;
@@ -1306,7 +1281,8 @@ TEST(Subnet6Test, clientClass) {
 // Checks that it is not allowed to add invalid pools.
 TEST(Subnet6Test, pool6Checks) {
 
-    auto subnet = Subnet6::create(IOAddress("2001:db8:1::"), 56, 1, 2, 3, 4);
+    auto subnet = Subnet6::create(IOAddress("2001:db8:1::"),
+                                  56, 1, 2, 3, 4, SubnetID(1));
 
     // this one is in subnet
     Pool6Ptr pool1(new Pool6(Lease::TYPE_NA, IOAddress("2001:db8:1:1::"), 64));
@@ -1379,7 +1355,8 @@ TEST(Subnet6Test, pool6Checks) {
 
 TEST(Subnet6Test, addOptions) {
     // Create as subnet to add options to it.
-    auto subnet = Subnet6::create(IOAddress("2001:db8:1::"), 56, 1, 2, 3, 4);
+    auto subnet = Subnet6::create(IOAddress("2001:db8:1::"),
+                                  56, 1, 2, 3, 4, SubnetID(1));
 
     // Differentiate options by their codes (100-109)
     for (uint16_t code = 100; code < 110; ++code) {
@@ -1403,10 +1380,9 @@ TEST(Subnet6Test, addOptions) {
 
     // Validate codes of options added to dhcp6 option space.
     uint16_t expected_code = 100;
-    for (OptionContainer::const_iterator option_desc = options->begin();
-         option_desc != options->end(); ++option_desc) {
-        ASSERT_TRUE(option_desc->option_);
-        EXPECT_EQ(expected_code, option_desc->option_->getType());
+    for (auto const& option_desc : *options) {
+        ASSERT_TRUE(option_desc.option_);
+        EXPECT_EQ(expected_code, option_desc.option_->getType());
         ++expected_code;
     }
 
@@ -1416,10 +1392,9 @@ TEST(Subnet6Test, addOptions) {
 
     // Validate codes of options added to isc option space.
     expected_code = 105;
-    for (OptionContainer::const_iterator option_desc = options->begin();
-         option_desc != options->end(); ++option_desc) {
-        ASSERT_TRUE(option_desc->option_);
-        EXPECT_EQ(expected_code, option_desc->option_->getType());
+    for (auto const& option_desc : *options) {
+        ASSERT_TRUE(option_desc.option_);
+        EXPECT_EQ(expected_code, option_desc.option_->getType());
         ++expected_code;
     }
 
@@ -1431,7 +1406,8 @@ TEST(Subnet6Test, addOptions) {
 
 TEST(Subnet6Test, addNonUniqueOptions) {
     // Create as subnet to add options to it.
-    auto subnet = Subnet6::create(IOAddress("2001:db8:1::"), 56, 1, 2, 3, 4);
+    auto subnet = Subnet6::create(IOAddress("2001:db8:1::"),
+                                  56, 1, 2, 3, 4, SubnetID(1));
 
     // Create a set of options with non-unique codes.
     for (int i = 0;  i < 2; ++i) {
@@ -1457,10 +1433,9 @@ TEST(Subnet6Test, addNonUniqueOptions) {
         // have been returned for the particular code.
         ASSERT_EQ(2, distance(range.first, range.second));
         // Check that returned options actually have the expected option code.
-        for (OptionContainerTypeIndex::const_iterator option_desc = range.first;
-             option_desc != range.second; ++option_desc) {
-            ASSERT_TRUE(option_desc->option_);
-            EXPECT_EQ(code, option_desc->option_->getType());
+        BOOST_FOREACH(auto const& option_desc, range) {
+            ASSERT_TRUE(option_desc.option_);
+            EXPECT_EQ(code, option_desc.option_->getType());
         }
     }
 
@@ -1473,7 +1448,8 @@ TEST(Subnet6Test, addNonUniqueOptions) {
 
 TEST(Subnet6Test, addPersistentOption) {
     // Create as subnet to add options to it.
-    auto subnet = Subnet6::create(IOAddress("2001:db8:1::"), 56, 1, 2, 3, 4);
+    auto subnet = Subnet6::create(IOAddress("2001:db8:1::"),
+                                  56, 1, 2, 3, 4, SubnetID(1));
 
     // Add 10 options to the subnet with option codes 100 - 109.
     for (uint16_t code = 100; code < 110; ++code) {
@@ -1511,7 +1487,8 @@ TEST(Subnet6Test, addPersistentOption) {
 }
 
 TEST(Subnet6Test, getOptions) {
-    auto subnet = Subnet6::create(IOAddress("2001:db8::"), 56, 1, 2, 3, 4);
+    auto subnet = Subnet6::create(IOAddress("2001:db8::"),
+                                  56, 1, 2, 3, 4, SubnetID(1));
 
     // Add 10 options to a "dhcp6" option space in the subnet.
     for (uint16_t code = 100; code < 110; ++code) {
@@ -1539,7 +1516,8 @@ TEST(Subnet6Test, getOptions) {
 TEST(Subnet6Test, addVendorOption) {
 
     // Create as subnet to add options to it.
-    auto subnet = Subnet6::create(IOAddress("2001:db8:1::"), 56, 1, 2, 3, 4);
+    auto subnet = Subnet6::create(IOAddress("2001:db8:1::"),
+                                  56, 1, 2, 3, 4, SubnetID(1));
 
     // Differentiate options by their codes (100-109)
     for (uint16_t code = 100; code < 110; ++code) {
@@ -1563,10 +1541,9 @@ TEST(Subnet6Test, addVendorOption) {
 
     // Validate codes of options added to dhcp6 option space.
     uint16_t expected_code = 100;
-    for (OptionContainer::const_iterator option_desc = options->begin();
-         option_desc != options->end(); ++option_desc) {
-        ASSERT_TRUE(option_desc->option_);
-        EXPECT_EQ(expected_code, option_desc->option_->getType());
+    for (auto const& option_desc : *options) {
+        ASSERT_TRUE(option_desc.option_);
+        EXPECT_EQ(expected_code, option_desc.option_->getType());
         ++expected_code;
     }
 
@@ -1576,10 +1553,9 @@ TEST(Subnet6Test, addVendorOption) {
 
     // Validate codes of options added to isc option space.
     expected_code = 105;
-    for (OptionContainer::const_iterator option_desc = options->begin();
-         option_desc != options->end(); ++option_desc) {
-        ASSERT_TRUE(option_desc->option_);
-        EXPECT_EQ(expected_code, option_desc->option_->getType());
+    for (auto const& option_desc : *options) {
+        ASSERT_TRUE(option_desc.option_);
+        EXPECT_EQ(expected_code, option_desc.option_->getType());
         ++expected_code;
     }
 
@@ -1591,7 +1567,8 @@ TEST(Subnet6Test, addVendorOption) {
 
 // This test verifies that inRange() and inPool() methods work properly.
 TEST(Subnet6Test, inRangeinPool) {
-    auto subnet = Subnet6::create(IOAddress("2001:db8::"), 32, 1, 2, 3, 4);
+    auto subnet = Subnet6::create(IOAddress("2001:db8::"),
+                                  32, 1, 2, 3, 4, SubnetID(1));
 
     // this one is in subnet
     Pool6Ptr pool1(new Pool6(Lease::TYPE_NA, IOAddress("2001:db8::10"),
@@ -1652,7 +1629,8 @@ TEST(Subnet6Test, inRangeinPool) {
 // This test verifies that inRange() and inPool() methods work properly
 // for prefixes too.
 TEST(Subnet6Test, PdinRangeinPool) {
-    auto subnet = Subnet6::create(IOAddress("2001:db8::"), 64, 1, 2, 3, 4);
+    auto subnet = Subnet6::create(IOAddress("2001:db8::"),
+                                  64, 1, 2, 3, 4, SubnetID(1));
 
     // this one is in subnet
     Pool6Ptr pool1(new Pool6(Lease::TYPE_PD, IOAddress("2001:db8::"),
@@ -1685,7 +1663,7 @@ TEST(Subnet6Test, PdinRangeinPool) {
 
 // This test checks if the toText() method returns text representation
 TEST(Subnet6Test, toText) {
-    Subnet6 subnet(IOAddress("2001:db8::"), 32, 1, 2, 3, 4);
+    Subnet6 subnet(IOAddress("2001:db8::"), 32, 1, 2, 3, 4, SubnetID(1));
     EXPECT_EQ("2001:db8::/32", subnet.toText());
 }
 
@@ -1721,7 +1699,7 @@ TEST(Subnet6Test, parsePrefix) {
 
 // This test checks if the get() method returns proper parameters
 TEST(Subnet6Test, get) {
-    Subnet6 subnet(IOAddress("2001:db8::"), 32, 1, 2, 3, 4);
+    Subnet6 subnet(IOAddress("2001:db8::"), 32, 1, 2, 3, 4, SubnetID(1));
     EXPECT_EQ("2001:db8::", subnet.get().first.toText());
     EXPECT_EQ(32, subnet.get().second);
 }
@@ -1729,7 +1707,7 @@ TEST(Subnet6Test, get) {
 // This trivial test checks if interface name is stored properly
 // in Subnet6 objects.
 TEST(Subnet6Test, iface) {
-    Subnet6 subnet(IOAddress("2001:db8::"), 32, 1, 2, 3, 4);
+    Subnet6 subnet(IOAddress("2001:db8::"), 32, 1, 2, 3, 4, SubnetID(1));
 
     EXPECT_TRUE(subnet.getIface().empty());
 
@@ -1741,7 +1719,8 @@ TEST(Subnet6Test, iface) {
 // later retrieved for a subnet6 object.
 TEST(Subnet6Test, interfaceId) {
     // Create as subnet to add options to it.
-    auto subnet = Subnet6::create(IOAddress("2001:db8:1::"), 56, 1, 2, 3, 4);
+    auto subnet = Subnet6::create(IOAddress("2001:db8:1::"),
+                                  56, 1, 2, 3, 4, SubnetID(1));
 
     EXPECT_FALSE(subnet->getInterfaceId());
 
@@ -1756,7 +1735,8 @@ TEST(Subnet6Test, interfaceId) {
 // disabled for a subnet. It also checks that the Rapid Commit
 // support is disabled by default.
 TEST(Subnet6Test, rapidCommit) {
-    Subnet6 subnet(IOAddress("2001:db8:1::"), 56, 1, 2, 3, 4);
+    Subnet6 subnet(IOAddress("2001:db8:1::"),
+                   56, 1, 2, 3, 4, SubnetID(1));
 
     // By default, the RC should be disabled.
     EXPECT_FALSE(subnet.getRapidCommit());
@@ -1774,7 +1754,8 @@ TEST(Subnet6Test, rapidCommit) {
 // states are instantiated for a subnet.
 TEST(Subnet6Test, createAllocatorsIterative) {
     // Create a subnet.
-    auto subnet = Subnet6::create(IOAddress("2001:db8:1::"), 56, 1, 2, 3, 4);
+    auto subnet = Subnet6::create(IOAddress("2001:db8:1::"),
+                                  56, 1, 2, 3, 4, SubnetID(1));
     ASSERT_TRUE(subnet);
     // NA pool.
     auto pool = boost::make_shared<Pool6>(Lease::TYPE_NA, IOAddress("2001:db8:1:1::"), 112);
@@ -1820,7 +1801,8 @@ TEST(Subnet6Test, createAllocatorsIterative) {
 // states are instantiated for a subnet.
 TEST(Subnet6Test, createAllocatorsRandom) {
     // Create a subnet.
-    auto subnet = Subnet6::create(IOAddress("2001:db8:1::"), 56, 1, 2, 3, 4);
+    auto subnet = Subnet6::create(IOAddress("2001:db8:1::"),
+                                  56, 1, 2, 3, 4, SubnetID(1));
     ASSERT_TRUE(subnet);
     // NA pool.
     auto pool = boost::make_shared<Pool6>(Lease::TYPE_NA, IOAddress("2001:db8:1:1::"), 112);
@@ -1866,7 +1848,8 @@ TEST(Subnet6Test, createAllocatorsRandom) {
 // states are instantiated for a subnet.
 TEST(Subnet6Test, createAllocatorsFreeLeaseQueue) {
     // Create a subnet.
-    auto subnet = Subnet6::create(IOAddress("2001:db8:1::"), 56, 1, 2, 3, 4);
+    auto subnet = Subnet6::create(IOAddress("2001:db8:1::"),
+                                  56, 1, 2, 3, 4, SubnetID(1));
     ASSERT_TRUE(subnet);
     // NA pool.
     auto pool = boost::make_shared<Pool6>(Lease::TYPE_NA, IOAddress("2001:db8:1:1::"), 112);
@@ -1911,7 +1894,8 @@ TEST(Subnet6Test, createAllocatorsFreeLeaseQueue) {
 
 // Test that it is not allowed to use the FLQ allocator for the address pools.
 TEST(Subnet6Test, createAllocatorsFreeLeaseQueueNotAllowed) {
-    auto subnet = Subnet6::create(IOAddress("2001:db8:1::"), 56, 1, 2, 3, 4);
+    auto subnet = Subnet6::create(IOAddress("2001:db8:1::"),
+                                  56, 1, 2, 3, 4, SubnetID(1));
     ASSERT_TRUE(subnet);
 
     subnet->setAllocatorType("flq");
@@ -1970,4 +1954,87 @@ TEST(SubnetFetcherTest, getSubnet6ById) {
     EXPECT_EQ("2001:db8:2::/64", subnet->toText());
 }
 
+// Test fixture for subnet identifier auto-generation.
+class SubnetIdTest : public LogContentTest {
+public:
+
+    /// @brief virtual destructor.
+    virtual ~SubnetIdTest() {
+        Subnet::resetSubnetID();
+    }
 };
+
+// Test class for subnets with id = 0.
+class TestSubnet : public Subnet {
+public:
+    // @brief Constructor.
+    //
+    // @param prefix subnet prefix.
+    // @param len prefix length for the subnet.
+    TestSubnet(const IOAddress& prefix, uint8_t len)
+        : Subnet(prefix, len, 0) {
+    }
+
+    // @brief Returns the default address that will be used for pool selection.
+    virtual IOAddress default_pool() const {
+        isc_throw(NotImplemented, "default_pool");
+    }
+
+    /// @brief Instantiates the allocators and their states.
+    virtual void createAllocators() {
+        isc_throw(NotImplemented, "createAllocators");
+    }
+
+    /// @brief Checks if used pool type is valid.
+    virtual void checkType(Lease::Type type) const {
+        isc_throw(NotImplemented, "checkType " << type);
+    }
+};
+
+// Type of pointers to test subnets.
+typedef boost::shared_ptr<TestSubnet> TestSubnetPtr;
+
+// Test subnet identifier auto-generation.
+TEST_F(SubnetIdTest, unnumbered) {
+    // Reset subnet identifier counter.
+    Subnet::resetSubnetID();
+
+    // First subnet.
+    IOAddress addr1("192.0.2.0");
+    uint8_t len1(25);
+    TestSubnetPtr subnet1;
+    ASSERT_NO_THROW(subnet1.reset(new TestSubnet(addr1, len1)));
+    ASSERT_TRUE(subnet1);
+    EXPECT_EQ(1, subnet1->getID());
+    EXPECT_EQ("192.0.2.0/25", subnet1->toText());
+
+    // Second subnet.
+    IOAddress addr2("192.0.2.128");
+    uint8_t len2(25);
+    TestSubnetPtr subnet2;
+    ASSERT_NO_THROW(subnet2.reset(new TestSubnet(addr2, len2)));
+    ASSERT_TRUE(subnet2);
+    EXPECT_EQ(2, subnet2->getID());
+    EXPECT_EQ("192.0.2.128/25", subnet2->toText());
+
+    // Reset subnet identifier counter again to get another log.
+    Subnet::resetSubnetID();
+
+    // Third subnet.
+    IOAddress addr3("2001:db8:1::");
+    uint8_t len3(64);
+    TestSubnetPtr subnet3;
+    ASSERT_NO_THROW(subnet3.reset(new TestSubnet(addr3, len3)));
+    ASSERT_TRUE(subnet3);
+    EXPECT_EQ(1, subnet3->getID());
+    EXPECT_EQ("2001:db8:1::/64", subnet3->toText());
+
+    // Subnet 1 and 3 are logged.
+    std::string msg = "DHCPSRV_CONFIGURED_SUBNET_WITHOUT_ID ";
+    msg += "a subnet was configured without an id: ";
+    addString(msg + subnet1->toText());
+    addString(msg + subnet3->toText());
+    EXPECT_TRUE(checkFile());
+}
+
+}
