@@ -1,4 +1,4 @@
-// Copyright (C) 2016-2020 Internet Systems Consortium, Inc. ("ISC")
+// Copyright (C) 2016-2024 Internet Systems Consortium, Inc. ("ISC")
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -27,7 +27,16 @@ namespace {
 
 /// @brief Test fixture class for @c TimerMgr.
 class TimerMgrTest : public ::testing::Test {
+public:
+
+    /// @brief Constructor
+    TimerMgrTest() = default;
+
+    /// @brief Destructor
+    virtual ~TimerMgrTest() = default;
+
 private:
+
     /// @brief Prepares the class for a test.
     virtual void SetUp();
 
@@ -161,7 +170,7 @@ TimerMgrTest::doWait(const long timeout, const bool /*call_receive*/) {
         io_service_->stop();
     }, timeout, IntervalTimer::ONE_SHOT);
     io_service_->run();
-    io_service_->get_io_service().reset();
+    io_service_->restart();
 }
 
 void
@@ -286,12 +295,12 @@ TimerMgrTest::testUnregisterTimers() {
     doWait(500);
 
     // Make sure that all timers have been executed at least once.
-    for (CallsCount::iterator it = calls_count_.begin();
-         it != calls_count_.end(); ++it) {
-        unsigned int calls_count = it->second;
+    size_t count = 0;
+    for (auto const& it : calls_count_) {
+        unsigned int calls_count = it.second;
         ASSERT_GT(calls_count, 0)
-            << "expected calls counter for timer"
-            << (std::distance(calls_count_.begin(), it) + 1)
+            << "expected calls counter for timer "
+            << ++count
             << " greater than 0";
     }
 
