@@ -142,6 +142,12 @@ public:
                         isc::data::ConstElementPtr user_context =
                         isc::data::ConstElementPtr()) const;
 
+    /// @brief Adds an IPv6 address to the host.
+    ///
+    /// @param host pointer to the host instance.
+    /// @param address an IPv6 address to be added as a string.
+    void addIPv6Address(const HostPtr& host, const std::string& address) const;
+
     /// @brief Pointer to the host data source
     HostDataSourcePtr hdsptr_;
 
@@ -549,7 +555,7 @@ public:
         isc::db::DatabaseConnection::db_lost_callback_ = 0;
         isc::db::DatabaseConnection::db_recovered_callback_ = 0;
         isc::db::DatabaseConnection::db_failed_callback_ = 0;
-        isc::dhcp::HostMgr::setIOService(io_service_);
+        isc::db::DatabaseConnection::setIOService(io_service_);
         isc::dhcp::TimerMgr::instance()->setIOService(io_service_);
         isc::dhcp::CfgMgr::instance().clear();
     }
@@ -558,7 +564,7 @@ public:
         isc::db::DatabaseConnection::db_lost_callback_ = 0;
         isc::db::DatabaseConnection::db_recovered_callback_ = 0;
         isc::db::DatabaseConnection::db_failed_callback_ = 0;
-        isc::dhcp::HostMgr::setIOService(isc::asiolink::IOServicePtr());
+        isc::db::DatabaseConnection::setIOService(isc::asiolink::IOServicePtr());
         isc::dhcp::TimerMgr::instance()->unregisterTimers();
         isc::dhcp::CfgMgr::instance().clear();
     }
@@ -600,6 +606,50 @@ public:
     /// string
     virtual std::string invalidConnectString() = 0;
 
+    /// @brief Verifies the host manager's behavior if DB connection can not be
+    /// established but succeeds on retry
+    ///
+    /// This function creates a host manager with a back end that supports
+    /// connectivity lost callback (currently only MySQL and PostgreSQL). It
+    /// verifies that connectivity is unavailable and then recovered on retry:
+    /// -# The registered DbLostCallback was invoked
+    /// -# The registered DbRecoveredCallback was invoked
+    void testRetryOpenDbLostAndRecoveredCallback();
+
+    /// @brief Verifies the host manager's behavior if DB connection can not be
+    /// established but fails on retry
+    ///
+    /// This function creates a host manager with a back end that supports
+    /// connectivity lost callback (currently only MySQL and PostgreSQL). It
+    /// It verifies that connectivity is unavailable and then fails again on
+    /// retry:
+    /// -# The registered DbLostCallback was invoked
+    /// -# The registered DbFailedCallback was invoked
+    void testRetryOpenDbLostAndFailedCallback();
+
+    /// @brief Verifies the host manager's behavior if DB connection can not be
+    /// established but succeeds on retry
+    ///
+    /// This function creates a host manager with a back end that supports
+    /// connectivity lost callback (currently only MySQL and PostgreSQL). It
+    /// verifies that connectivity is unavailable and then recovered on retry:
+    /// -# The registered DbLostCallback was invoked
+    /// -# The registered DbRecoveredCallback was invoked after two reconnect
+    /// attempts (once failing and second triggered by timer)
+    void testRetryOpenDbLostAndRecoveredAfterTimeoutCallback();
+
+    /// @brief Verifies the host manager's behavior if DB connection can not be
+    /// established but fails on retry
+    ///
+    /// This function creates a host manager with a back end that supports
+    /// connectivity lost callback (currently only MySQL and PostgreSQL). It
+    /// It verifies that connectivity is unavailable and then fails again on
+    /// retry:
+    /// -# The registered DbLostCallback was invoked
+    /// -# The registered DbFailedCallback was invoked after two reconnect
+    /// attempts (once failing and second triggered by timer)
+    void testRetryOpenDbLostAndFailedAfterTimeoutCallback();
+
     /// @brief Verifies open failures do NOT invoke db lost callback
     ///
     /// The db lost callback should only be invoked after successfully
@@ -614,7 +664,7 @@ public:
     /// verifies connectivity by issuing a known valid query. Next it simulates
     /// connectivity lost by identifying and closing the socket connection to
     /// the CB backend. It then reissues the query and verifies that:
-    /// -# The Query throws  DbOperationError (rather than exiting)
+    /// -# The Query throws DbOperationError (rather than exiting)
     /// -# The registered DbLostCallback was invoked
     /// -# The registered DbRecoveredCallback was invoked
     void testDbLostAndRecoveredCallback();
@@ -626,7 +676,7 @@ public:
     /// verifies connectivity by issuing a known valid query. Next it simulates
     /// connectivity lost by identifying and closing the socket connection to
     /// the CB backend. It then reissues the query and verifies that:
-    /// -# The Query throws  DbOperationError (rather than exiting)
+    /// -# The Query throws DbOperationError (rather than exiting)
     /// -# The registered DbLostCallback was invoked
     /// -# The registered DbFailedCallback was invoked
     void testDbLostAndFailedCallback();
@@ -638,7 +688,7 @@ public:
     /// verifies connectivity by issuing a known valid query. Next it simulates
     /// connectivity lost by identifying and closing the socket connection to
     /// the CB backend. It then reissues the query and verifies that:
-    /// -# The Query throws  DbOperationError (rather than exiting)
+    /// -# The Query throws DbOperationError (rather than exiting)
     /// -# The registered DbLostCallback was invoked
     /// -# The registered DbRecoveredCallback was invoked after two reconnect
     /// attempts (once failing and second triggered by timer)
@@ -651,7 +701,7 @@ public:
     /// verifies connectivity by issuing a known valid query. Next it simulates
     /// connectivity lost by identifying and closing the socket connection to
     /// the CB backend. It then reissues the query and verifies that:
-    /// -# The Query throws  DbOperationError (rather than exiting)
+    /// -# The Query throws DbOperationError (rather than exiting)
     /// -# The registered DbLostCallback was invoked
     /// -# The registered DbFailedCallback was invoked after two reconnect
     /// attempts (once failing and second triggered by timer)
@@ -740,6 +790,23 @@ protected:
                   const isc::asiolink::IOAddress& address,
                   const uint8_t prefix_len = 128);
 
+    /// @brief Inserts IPv6 reservation into the host data source.
+    ///
+    /// @param data_source Reference to the data source to which the reservation
+    /// should be inserted.
+    /// @param duid Pointer to the DUID to be associated with the reservation.
+    /// @param subnet_id IPv6 subnet id.
+    /// @param addresses IPv6 addresses/prefixes to be reserved.
+    /// @param prefix_len Prefix length. The default value is 128 which
+    /// indicates that the reservation is for an IPv6 address rather than a
+    /// prefix. Notice that this is common for all addresses in given vector
+    /// of addresses.
+    void addHost6(BaseHostDataSource& data_source,
+                  const DuidPtr& duid,
+                  const SubnetID& subnet_id,
+                  const std::vector<isc::asiolink::IOAddress>& addresses,
+                  const uint8_t prefix_len = 128);
+
     /// @brief This test verifies that HostMgr returns all reservations for the
     /// specified HW address.
     ///
@@ -929,6 +996,31 @@ protected:
     void testGetAll6BySubnetIP(BaseHostDataSource& data_source1,
                                BaseHostDataSource& data_source2);
 
+    /// @brief This test verifies that HostMgr returns all reservations for the
+    /// specified IPv6 address.
+    ///
+    /// If reservations are added to different host data sources, it is expected
+    /// that the @c HostMgr will retrieve reservations from both of them.
+    ///
+    /// @param data_source1 Host data source to which first reservation is
+    /// inserted.
+    /// @param data_source2 Host data source to which second reservation is
+    /// inserted.
+    void testGetAll6ByIP(BaseHostDataSource& data_source1,
+                         BaseHostDataSource& data_source2);
+
+    /// @brief This test verifies that HostMgr returns all reservations for the
+    /// specified IPv6 prefix/es.
+    ///
+    /// If reservations are added to different host data sources, it is expected
+    /// that the @c HostMgr will retrieve reservations from both of them.
+    ///
+    /// @param data_source1 Host data source to which first reservation is
+    /// inserted.
+    /// @param data_source2 Host data source to which second reservation is
+    /// inserted.
+    void testGetAll6ByIpPrefix(BaseHostDataSource& data_source1, BaseHostDataSource& data_source2);
+
     /// @brief This test verifies that HostMgr adds the reservations to any
     /// data source.
     ///
@@ -986,7 +1078,7 @@ protected:
 
     /// @brief Utility function that returns true if a given data source
     /// is primary (it isn't an alternate source).
-    /// @param data_source  Host data source to check.
+    /// @param data_source Host data source to check.
     /// @return True if the data source is primary. Otherwise, false.
     bool isPrimaryDataSource(const BaseHostDataSource& data_source) const;
 
