@@ -1,4 +1,4 @@
-// Copyright (C) 2012-2020 Internet Systems Consortium, Inc. ("ISC")
+// Copyright (C) 2012-2024 Internet Systems Consortium, Inc. ("ISC")
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -638,7 +638,7 @@ MasterLoader::MasterLoaderImpl::generateForIter(const std::string& str,
 {
   std::string rstr;
 
-  for (std::string::const_iterator it = str.begin(); it != str.end();) {
+  for (auto it = str.begin(); it != str.end();) {
       switch (*it) {
       case '$':
           // This is the case when the '$' character is encountered in
