@@ -1,4 +1,4 @@
-// Copyright (C) 2017-2022 Internet Systems Consortium, Inc. ("ISC")
+// Copyright (C) 2017-2024 Internet Systems Consortium, Inc. ("ISC")
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -409,9 +409,8 @@ public:
     ///
     /// Removes active HTTP clients.
     virtual ~HttpListenerTest() {
-        for (auto client = clients_.begin(); client != clients_.end();
-             ++client) {
-            (*client)->close();
+        for (auto const& client : clients_) {
+            client->close();
         }
     }
 
@@ -444,7 +443,7 @@ public:
     /// @param timeout Optional value specifying for how long the io service
     /// should be ran.
     void runIOService(long timeout = 0) {
-        io_service_.get_io_service().reset();
+        io_service_.restart();
 
         if (timeout > 0) {
             run_io_service_timer_.setup(std::bind(&HttpListenerTest::timeoutHandler,
@@ -452,7 +451,7 @@ public:
                                         timeout, IntervalTimer::ONE_SHOT);
         }
         io_service_.run();
-        io_service_.get_io_service().reset();
+        io_service_.restart();
         io_service_.poll();
     }
 
@@ -939,7 +938,7 @@ TEST_F(HttpListenerTest, invalidIdleTimeout) {
 // This test verifies that listener can't be bound to the port to which
 // other server is bound.
 TEST_F(HttpListenerTest, addressInUse) {
-    tcp::acceptor acceptor(io_service_.get_io_service());
+    tcp::acceptor acceptor(io_service_.getInternalIOService());
     // Use other port than SERVER_PORT to make sure that this TCP connection
     // doesn't affect subsequent tests.
     tcp::endpoint endpoint(address::from_string(SERVER_ADDRESS),
@@ -1064,7 +1063,7 @@ public:
         ASSERT_NO_THROW(listener_.start());
 
         // Create a client and specify the URL on which the server can be reached.
-        HttpClient client(io_service_);
+        HttpClient client(io_service_, false);
         Url url("http://127.0.0.1:18123");
 
         // Initiate request to the server.
@@ -1122,7 +1121,7 @@ public:
         ASSERT_NO_THROW(listener2_.start());
 
         // Create the client. It will be communicating with the two servers.
-        HttpClient client(io_service_);
+        HttpClient client(io_service_, false);
 
         // Specify the URLs on which the servers are available.
         Url url1("http://127.0.0.1:18123");
@@ -1179,7 +1178,7 @@ public:
         ASSERT_NO_THROW(listener_.start());
 
         // Create the client.
-        HttpClient client(io_service_);
+        HttpClient client(io_service_, false);
 
         // Specify the URL on which the server is available.
         Url url("http://127.0.0.1:18123");
@@ -1239,7 +1238,7 @@ public:
         ASSERT_NO_THROW(listener3_.start());
 
         // Create the client that will communicate with this server.
-        HttpClient client(io_service_);
+        HttpClient client(io_service_, false);
 
         // Specify the URL of this server.
         Url url("http://127.0.0.1:18125");
@@ -1294,7 +1293,7 @@ public:
     /// server is unreachable.
     void testUnreachable () {
         // Create the client.
-        HttpClient client(io_service_);
+        HttpClient client(io_service_, false);
 
         // Specify the URL of the server. This server is down.
         Url url("http://127.0.0.1:18123");
@@ -1323,7 +1322,7 @@ public:
         ASSERT_NO_THROW(listener_.start());
 
         // Create the client.
-        HttpClient client(io_service_);
+        HttpClient client(io_service_, false);
 
         // Specify the URL of the server.
         Url url("http://127.0.0.1:18123");
@@ -1360,7 +1359,7 @@ public:
         ASSERT_NO_THROW(listener_.start());
 
         // Create the client.
-        HttpClient client(io_service_);
+        HttpClient client(io_service_, false);
 
         // Specify the URL of the server.
         Url url("http://127.0.0.1:18123");
@@ -1425,7 +1424,7 @@ public:
         ASSERT_NO_THROW(listener_.start());
 
         // Create the client.
-        HttpClient client(io_service_);
+        HttpClient client(io_service_, false);
 
         // Specify the URL of the server.
         Url url("http://127.0.0.1:18123");
@@ -1499,7 +1498,7 @@ public:
         ASSERT_NO_THROW(listener_.start());
 
         // Create the client.
-        HttpClient client(io_service_);
+        HttpClient client(io_service_, false);
 
         // Specify the URL of the server.
         Url url("http://127.0.0.1:18123");
@@ -1582,7 +1581,7 @@ public:
         ASSERT_NO_THROW(listener_.start());
 
         // Create a client and specify the URL on which the server can be reached.
-        HttpClient client(io_service_);
+        HttpClient client(io_service_, false);
         Url url("http://127.0.0.1:18123");
 
         // Initiate request to the server.
@@ -1677,7 +1676,7 @@ public:
         ASSERT_NO_THROW(listener_.start());
 
         // Create a client and specify the URL on which the server can be reached.
-        HttpClient client(io_service_);
+        HttpClient client(io_service_, false);
         Url url("http://127.0.0.1:18123");
 
         // Initiate request to the server.
@@ -1799,7 +1798,7 @@ public:
 
     /// @brief Simulates external registery of Connection TCP sockets
     ///
-    /// Provides methods compatible with Connection callbacks for connnect
+    /// Provides methods compatible with Connection callbacks for connect
     /// and close operations.
     class ExternalMonitor {
     public:
