@@ -1,4 +1,4 @@
-// Copyright (C) 2013-2023 Internet Systems Consortium, Inc. ("ISC")
+// Copyright (C) 2013-2024 Internet Systems Consortium, Inc. ("ISC")
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -265,6 +265,18 @@ public:
     configGetHandler(const std::string& command,
                      isc::data::ConstElementPtr args);
 
+    /// @brief handler for config-hash-get command
+    ///
+    /// This method handles the config-hash-get command, which retrieves
+    /// the current configuration and returns it in response.
+    ///
+    /// @param command (ignored)
+    /// @param args (ignored)
+    /// @return hash of current configuration wrapped in a response
+    isc::data::ConstElementPtr
+    configHashGetHandler(const std::string& command,
+                         isc::data::ConstElementPtr args);
+
     /// @brief handler for config-write command
     ///
     /// This handle processes write-config command, which writes the
@@ -640,9 +652,25 @@ private:
     /// @brief Singleton instance value.
     static DControllerBasePtr controller_;
 
-// DControllerTest is named a friend class to facilitate unit testing while
-// leaving the intended member scopes intact.
-friend class DControllerTest;
+    // DControllerTest is named a friend class to facilitate unit testing while
+    // leaving the intended member scopes intact.
+    friend class DControllerTest;
+
+    /// @brief Structure used in parseArgs() to reset arguments in case parseArgs() is called again.
+    struct ExhaustOptions {
+        ExhaustOptions(int argc, char* argv[], std::string opts)
+            : argc_(argc), argv_(argv), opts_(opts) {
+        }
+        ~ExhaustOptions() {
+            while (getopt(argc_, argv_, opts_.c_str()) != -1) {
+            }
+        }
+
+    private:
+        int argc_;
+        char** argv_;
+        std::string opts_;
+    };
 };
 
 }  // namespace process
