@@ -1,4 +1,4 @@
-// Copyright (C) 2013-2021 Internet Systems Consortium, Inc. ("ISC")
+// Copyright (C) 2013-2024 Internet Systems Consortium, Inc. ("ISC")
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -10,6 +10,7 @@
 #include <asiolink/testutils/timed_signal.h>
 #include <cc/command_interpreter.h>
 #include <process/testutils/d_test_stubs.h>
+#include <testutils/gtest_utils.h>
 
 #include <boost/date_time/posix_time/posix_time.hpp>
 #include <gtest/gtest.h>
@@ -79,7 +80,7 @@ TEST_F(DStubControllerTest, commandLineArgs) {
                      const_cast<char*>("cfgName"),
                      const_cast<char*>("-d") };
     int argc = 4;
-    EXPECT_NO_THROW(parseArgs(argc, argv));
+    EXPECT_NO_THROW_LOG(parseArgs(argc, argv));
 
     // Verify that verbose is true.
     EXPECT_TRUE(checkVerbose(true));
@@ -92,20 +93,20 @@ TEST_F(DStubControllerTest, commandLineArgs) {
     xopt[1] =  *DStubController::stub_option_x_;
     char* argv1[] = { const_cast<char*>("progName"), xopt};
     argc = 2;
-    EXPECT_NO_THROW (parseArgs(argc, argv1));
+    EXPECT_NO_THROW_LOG(parseArgs(argc, argv1));
 
     // Verify that an unknown option is detected.
     char* argv2[] = { const_cast<char*>("progName"),
                       const_cast<char*>("-bs") };
     argc = 2;
-    EXPECT_THROW (parseArgs(argc, argv2), InvalidUsage);
+    EXPECT_THROW_MSG(parseArgs(argc, argv2), InvalidUsage, "unsupported option: -b");
 
     // Verify that extraneous information is detected.
     char* argv3[] = { const_cast<char*>("progName"),
                       const_cast<char*>("extra"),
                       const_cast<char*>("information") };
     argc = 3;
-    EXPECT_THROW (parseArgs(argc, argv3), InvalidUsage);
+    EXPECT_THROW_MSG(parseArgs(argc, argv3), InvalidUsage, "extraneous command line information");
 }
 
 /// @brief Tests application process creation and initialization.
@@ -188,6 +189,23 @@ TEST_F(DStubControllerTest, launchNormalShutdown) {
                 elapsed_time.total_milliseconds() <= 2300);
 }
 
+/// @brief A variant of the launch and normal shutdown test using a callback.
+TEST_F(DStubControllerTest, launchNormalShutdownWithCallback) {
+    // Write the valid, empty, config and then run launch() for 1000 ms
+    // Access to the internal state.
+    auto callback = [&] { EXPECT_FALSE(getProcess()->shouldShutdown()); };
+    time_duration elapsed_time;
+    ASSERT_NO_THROW(runWithConfig("{}", 2000,
+                                  static_cast<const TestCallback&>(callback),
+                                  elapsed_time));
+
+    // Verify that duration of the run invocation is the same as the
+    // timer duration.  This demonstrates that the shutdown was driven
+    // by an io_service event and callback.
+    EXPECT_TRUE(elapsed_time.total_milliseconds() >= 1900 &&
+                elapsed_time.total_milliseconds() <= 2300);
+}
+
 /// @brief Tests launch with an non-existing configuration file.
 TEST_F(DStubControllerTest, nonExistingConfigFile) {
     // command line to run standalone
